| Copyright | Will Thompson and Iñaki García Etxebarria |
|---|---|
| License | LGPL-2.1 |
| Maintainer | Iñaki García Etxebarria |
| Safe Haskell | None |
| Language | Haskell2010 |
GI.Gio.Interfaces.Action
Description
GAction represents a single named action.
The main interface to an action is that it can be activated with
actionActivate. This results in the 'activate' signal being
emitted. An activation has a GVariant parameter (which may be
NULL). The correct type for the parameter is determined by a static
parameter type (which is given at construction time).
An action may optionally have a state, in which case the state may be
set with actionChangeState. This call takes a [typegLib.Variant]. The
correct type for the state is determined by a static state type
(which is given at construction time).
The state may have a hint associated with it, specifying its valid range.
GAction is merely the interface to the concept of an action, as
described above. Various implementations of actions exist, including
SimpleAction.
In all cases, the implementing class is responsible for storing the
name of the action, the parameter type, the enabled state, the optional
state type and the state and emitting the appropriate signals when these
change. The implementor is responsible for filtering calls to
actionActivate and actionChangeState
for type safety and for the state being enabled.
Probably the only useful thing to do with a GAction is to put it
inside of a SimpleActionGroup.
Synopsis
- newtype Action = Action (ManagedPtr Action)
- class (GObject o, IsDescendantOf Action o) => IsAction o
- toAction :: (MonadIO m, IsAction o) => o -> m Action
- type family ResolveActionMethod (t :: Symbol) o where ...
- data ActionActivateMethodInfo
- actionActivate :: (HasCallStack, MonadIO m, IsAction a) => a -> Maybe GVariant -> m ()
- data ActionChangeStateMethodInfo
- actionChangeState :: (HasCallStack, MonadIO m, IsAction a) => a -> GVariant -> m ()
- data ActionGetEnabledMethodInfo
- actionGetEnabled :: (HasCallStack, MonadIO m, IsAction a) => a -> m Bool
- data ActionGetNameMethodInfo
- actionGetName :: (HasCallStack, MonadIO m, IsAction a) => a -> m Text
- data ActionGetParameterTypeMethodInfo
- actionGetParameterType :: (HasCallStack, MonadIO m, IsAction a) => a -> m (Maybe VariantType)
- data ActionGetStateMethodInfo
- actionGetState :: (HasCallStack, MonadIO m, IsAction a) => a -> m (Maybe GVariant)
- data ActionGetStateHintMethodInfo
- actionGetStateHint :: (HasCallStack, MonadIO m, IsAction a) => a -> m (Maybe GVariant)
- data ActionGetStateTypeMethodInfo
- actionGetStateType :: (HasCallStack, MonadIO m, IsAction a) => a -> m (Maybe VariantType)
- actionNameIsValid :: (HasCallStack, MonadIO m) => Text -> m Bool
- actionParseDetailedName :: (HasCallStack, MonadIO m) => Text -> m (Text, Maybe GVariant)
- actionPrintDetailedName :: (HasCallStack, MonadIO m) => Text -> Maybe GVariant -> m Text
- data ActionEnabledPropertyInfo
- actionEnabled :: AttrLabelProxy "enabled"
- getActionEnabled :: (MonadIO m, IsAction o) => o -> m Bool
- data ActionNamePropertyInfo
- actionName :: AttrLabelProxy "name"
- getActionName :: (MonadIO m, IsAction o) => o -> m Text
- data ActionParameterTypePropertyInfo
- actionParameterType :: AttrLabelProxy "parameterType"
- getActionParameterType :: (MonadIO m, IsAction o) => o -> m (Maybe VariantType)
- data ActionStatePropertyInfo
- actionState :: AttrLabelProxy "state"
- getActionState :: (MonadIO m, IsAction o) => o -> m (Maybe GVariant)
- data ActionStateTypePropertyInfo
- actionStateType :: AttrLabelProxy "stateType"
- getActionStateType :: (MonadIO m, IsAction o) => o -> m (Maybe VariantType)
Exported types
Memory-managed wrapper type.
Constructors
| Action (ManagedPtr Action) |
Instances
class (GObject o, IsDescendantOf Action o) => IsAction o Source #
Instances
| (GObject o, IsDescendantOf Action o) => IsAction o Source # | |
Defined in GI.Gio.Interfaces.Action | |
Methods
Click to display all available methods, including inherited ones
Methods
activate, bindProperty, bindPropertyFull, changeState, forceFloating, freezeNotify, getv, isFloating, notify, notifyByPspec, ref, refSink, runDispose, stealData, stealQdata, thawNotify, unref, watchClosure.
Getters
getData, getEnabled, getName, getParameterType, getProperty, getQdata, getState, getStateHint, getStateType.
Setters
type family ResolveActionMethod (t :: Symbol) o where ... Source #
Equations
activate
data ActionActivateMethodInfo Source #
Instances
| (signature ~ (Maybe GVariant -> m ()), MonadIO m, IsAction a) => OverloadedMethod ActionActivateMethodInfo a signature Source # | |
Defined in GI.Gio.Interfaces.Action Methods overloadedMethod :: a -> signature # | |
| OverloadedMethodInfo ActionActivateMethodInfo (a :: Type) Source # | |
Defined in GI.Gio.Interfaces.Action Methods | |
Arguments
| :: (HasCallStack, MonadIO m, IsAction a) | |
| => a |
|
| -> Maybe GVariant |
|
| -> m () |
Activates the action.
parameter must be the correct type of parameter for the action (ie:
the parameter type given at construction time). If the parameter
type was NULL then parameter must also be NULL.
If the parameter [typegLib.Variant] is floating, it is consumed.
Since: 2.28
changeState
data ActionChangeStateMethodInfo Source #
Instances
| (signature ~ (GVariant -> m ()), MonadIO m, IsAction a) => OverloadedMethod ActionChangeStateMethodInfo a signature Source # | |
Defined in GI.Gio.Interfaces.Action Methods overloadedMethod :: a -> signature # | |
| OverloadedMethodInfo ActionChangeStateMethodInfo (a :: Type) Source # | |
Defined in GI.Gio.Interfaces.Action Methods | |
Arguments
| :: (HasCallStack, MonadIO m, IsAction a) | |
| => a |
|
| -> GVariant |
|
| -> m () |
Request for the state of action to be changed to value.
The action must be stateful and value must be of the correct type.
See actionGetStateType.
This call merely requests a change. The action may refuse to change
its state or may change its state to something other than value.
See actionGetStateHint.
If the value [typegLib.Variant] is floating, it is consumed.
Since: 2.30
getEnabled
data ActionGetEnabledMethodInfo Source #
Instances
| (signature ~ m Bool, MonadIO m, IsAction a) => OverloadedMethod ActionGetEnabledMethodInfo a signature Source # | |
Defined in GI.Gio.Interfaces.Action Methods overloadedMethod :: a -> signature # | |
| OverloadedMethodInfo ActionGetEnabledMethodInfo (a :: Type) Source # | |
Defined in GI.Gio.Interfaces.Action Methods | |
Arguments
| :: (HasCallStack, MonadIO m, IsAction a) | |
| => a |
|
| -> m Bool | Returns: whether the action is enabled |
Checks if action is currently enabled.
An action must be enabled in order to be activated or in order to have its state changed from outside callers.
Since: 2.28
getName
data ActionGetNameMethodInfo Source #
Instances
| (signature ~ m Text, MonadIO m, IsAction a) => OverloadedMethod ActionGetNameMethodInfo a signature Source # | |
Defined in GI.Gio.Interfaces.Action Methods overloadedMethod :: a -> signature # | |
| OverloadedMethodInfo ActionGetNameMethodInfo (a :: Type) Source # | |
Defined in GI.Gio.Interfaces.Action Methods | |
Arguments
| :: (HasCallStack, MonadIO m, IsAction a) | |
| => a |
|
| -> m Text | Returns: the name of the action |
Queries the name of action.
Since: 2.28
getParameterType
data ActionGetParameterTypeMethodInfo Source #
Instances
| (signature ~ m (Maybe VariantType), MonadIO m, IsAction a) => OverloadedMethod ActionGetParameterTypeMethodInfo a signature Source # | |
Defined in GI.Gio.Interfaces.Action Methods overloadedMethod :: a -> signature # | |
| OverloadedMethodInfo ActionGetParameterTypeMethodInfo (a :: Type) Source # | |
Defined in GI.Gio.Interfaces.Action Methods | |
actionGetParameterType Source #
Arguments
| :: (HasCallStack, MonadIO m, IsAction a) | |
| => a |
|
| -> m (Maybe VariantType) | Returns: the parameter type |
Queries the type of the parameter that must be given when activating
action.
When activating the action using actionActivate, the
[typegLib.Variant] given to that function must be of the type returned by
this function.
In the case that this function returns NULL, you must not give any
[typegLib.Variant], but NULL instead.
Since: 2.28
getState
data ActionGetStateMethodInfo Source #
Instances
| (signature ~ m (Maybe GVariant), MonadIO m, IsAction a) => OverloadedMethod ActionGetStateMethodInfo a signature Source # | |
Defined in GI.Gio.Interfaces.Action Methods overloadedMethod :: a -> signature # | |
| OverloadedMethodInfo ActionGetStateMethodInfo (a :: Type) Source # | |
Defined in GI.Gio.Interfaces.Action Methods | |
Arguments
| :: (HasCallStack, MonadIO m, IsAction a) | |
| => a |
|
| -> m (Maybe GVariant) | Returns: the current state of the action |
Queries the current state of action.
If the action is not stateful then NULL will be returned. If the
action is stateful then the type of the return value is the type
given by actionGetStateType.
The return value (if non-NULL) should be freed with
variantUnref when it is no longer required.
Since: 2.28
getStateHint
data ActionGetStateHintMethodInfo Source #
Instances
| (signature ~ m (Maybe GVariant), MonadIO m, IsAction a) => OverloadedMethod ActionGetStateHintMethodInfo a signature Source # | |
Defined in GI.Gio.Interfaces.Action Methods overloadedMethod :: a -> signature # | |
| OverloadedMethodInfo ActionGetStateHintMethodInfo (a :: Type) Source # | |
Defined in GI.Gio.Interfaces.Action Methods | |
Arguments
| :: (HasCallStack, MonadIO m, IsAction a) | |
| => a |
|
| -> m (Maybe GVariant) | Returns: the state range hint |
Requests a hint about the valid range of values for the state of
action.
If NULL is returned it either means that the action is not stateful
or that there is no hint about the valid range of values for the
state of the action.
If a [typegLib.Variant] array is returned then each item in the array is a
possible value for the state. If a [typegLib.Variant] pair (ie: two-tuple) is
returned then the tuple specifies the inclusive lower and upper bound
of valid values for the state.
In any case, the information is merely a hint. It may be possible to have a state value outside of the hinted range and setting a value within the range may fail.
The return value (if non-NULL) should be freed with
variantUnref when it is no longer required.
Since: 2.28
getStateType
data ActionGetStateTypeMethodInfo Source #
Instances
| (signature ~ m (Maybe VariantType), MonadIO m, IsAction a) => OverloadedMethod ActionGetStateTypeMethodInfo a signature Source # | |
Defined in GI.Gio.Interfaces.Action Methods overloadedMethod :: a -> signature # | |
| OverloadedMethodInfo ActionGetStateTypeMethodInfo (a :: Type) Source # | |
Defined in GI.Gio.Interfaces.Action Methods | |
Arguments
| :: (HasCallStack, MonadIO m, IsAction a) | |
| => a |
|
| -> m (Maybe VariantType) | Returns: the state type, if the action is stateful |
Queries the type of the state of action.
If the action is stateful (e.g. created with
simpleActionNewStateful) then this function returns the
[typegLib.VariantType] of the state. This is the type of the initial value
given as the state. All calls to actionChangeState must give a
[typegLib.Variant] of this type and actionGetState will return a
[typegLib.Variant] of the same type.
If the action is not stateful (e.g. created with simpleActionNew)
then this function will return NULL. In that case, actionGetState
will return NULL and you must not call actionChangeState.
Since: 2.28
nameIsValid
Arguments
| :: (HasCallStack, MonadIO m) | |
| => Text |
|
| -> m Bool | Returns: |
Checks if actionName is valid.
actionName is valid if it consists only of alphanumeric characters,
plus - and .. The empty string is not a valid action name.
It is an error to call this function with a non-UTF-8 actionName.
actionName must not be NULL.
Since: 2.38
parseDetailedName
actionParseDetailedName Source #
Arguments
| :: (HasCallStack, MonadIO m) | |
| => Text |
|
| -> m (Text, Maybe GVariant) | (Can throw |
Parses a detailed action name into its separate name and target components.
Detailed action names can have three formats.
The first format is used to represent an action name with no target
value and consists of just an action name containing no whitespace
nor the characters :, ( or ). For example: app.action.
The second format is used to represent an action with a target value
that is a non-empty string consisting only of alphanumerics, plus -
and .. In that case, the action name and target value are
separated by a double colon (::). For example:
app.action::target.
The third format is used to represent an action with any type of
target value, including strings. The target value follows the action
name, surrounded in parens. For example: app.action(42). The
target value is parsed using variantParse. If a tuple-typed
value is desired, it must be specified in the same way, resulting in
two sets of parens, for example: app.action((1,2,3)). A string
target can be specified this way as well: app.action('target').
For strings, this third format must be used if target value is
empty or contains characters other than alphanumerics, - and ..
If this function returns TRUE, a non-NULL value is guaranteed to be returned
in actionName (if a pointer is passed in). A NULL value may still be
returned in targetValue, as the detailedName may not contain a target.
If returned, the [typegLib.Variant] in targetValue is guaranteed to not be floating.
Since: 2.38
printDetailedName
actionPrintDetailedName Source #
Arguments
| :: (HasCallStack, MonadIO m) | |
| => Text |
|
| -> Maybe GVariant |
|
| -> m Text | Returns: a detailed format string |
Formats a detailed action name from actionName and targetValue.
It is an error to call this function with an invalid action name.
This function is the opposite of actionParseDetailedName.
It will produce a string that can be parsed back to the actionName
and targetValue by that function.
See that function for the types of strings that will be printed by this function.
Since: 2.38
Properties
enabled
If action is currently enabled.
If the action is disabled then calls to actionActivate and
actionChangeState have no effect.
Since: 2.28
data ActionEnabledPropertyInfo Source #
Instances
actionEnabled :: AttrLabelProxy "enabled" Source #
getActionEnabled :: (MonadIO m, IsAction o) => o -> m Bool Source #
Get the value of the “enabled” property.
When overloading is enabled, this is equivalent to
get action #enabled
name
The name of the action. This is mostly meaningful for identifying
the action once it has been added to a [typegio.ActionGroup]. It is immutable.
Since: 2.28
data ActionNamePropertyInfo Source #
Instances
| AttrInfo ActionNamePropertyInfo Source # | |||||||||||||||||||||||||||||||||
Defined in GI.Gio.Interfaces.Action Associated Types
Methods attrGet :: AttrBaseTypeConstraint ActionNamePropertyInfo o => o -> IO (AttrGetType ActionNamePropertyInfo) # attrSet :: (AttrBaseTypeConstraint ActionNamePropertyInfo o, AttrSetTypeConstraint ActionNamePropertyInfo b) => o -> b -> IO () # attrClear :: AttrBaseTypeConstraint ActionNamePropertyInfo o => o -> IO () # attrConstruct :: (AttrBaseTypeConstraint ActionNamePropertyInfo o, AttrSetTypeConstraint ActionNamePropertyInfo b) => b -> IO (GValueConstruct o) # attrTransfer :: (AttrBaseTypeConstraint ActionNamePropertyInfo o, AttrTransferTypeConstraint ActionNamePropertyInfo b) => Proxy o -> b -> IO (AttrTransferType ActionNamePropertyInfo) # | |||||||||||||||||||||||||||||||||
| type AttrAllowedOps ActionNamePropertyInfo Source # | |||||||||||||||||||||||||||||||||
Defined in GI.Gio.Interfaces.Action | |||||||||||||||||||||||||||||||||
| type AttrBaseTypeConstraint ActionNamePropertyInfo Source # | |||||||||||||||||||||||||||||||||
Defined in GI.Gio.Interfaces.Action | |||||||||||||||||||||||||||||||||
| type AttrGetType ActionNamePropertyInfo Source # | |||||||||||||||||||||||||||||||||
Defined in GI.Gio.Interfaces.Action | |||||||||||||||||||||||||||||||||
| type AttrLabel ActionNamePropertyInfo Source # | |||||||||||||||||||||||||||||||||
Defined in GI.Gio.Interfaces.Action | |||||||||||||||||||||||||||||||||
| type AttrOrigin ActionNamePropertyInfo Source # | |||||||||||||||||||||||||||||||||
Defined in GI.Gio.Interfaces.Action | |||||||||||||||||||||||||||||||||
| type AttrSetTypeConstraint ActionNamePropertyInfo Source # | |||||||||||||||||||||||||||||||||
Defined in GI.Gio.Interfaces.Action | |||||||||||||||||||||||||||||||||
| type AttrTransferType ActionNamePropertyInfo Source # | |||||||||||||||||||||||||||||||||
Defined in GI.Gio.Interfaces.Action | |||||||||||||||||||||||||||||||||
| type AttrTransferTypeConstraint ActionNamePropertyInfo Source # | |||||||||||||||||||||||||||||||||
Defined in GI.Gio.Interfaces.Action | |||||||||||||||||||||||||||||||||
actionName :: AttrLabelProxy "name" Source #
getActionName :: (MonadIO m, IsAction o) => o -> m Text Source #
Get the value of the “name” property.
When overloading is enabled, this is equivalent to
get action #name
parameterType
The type of the parameter that must be given when activating the
action. This is immutable, and may be NULL if no parameter is needed when
activating the action.
Since: 2.28
data ActionParameterTypePropertyInfo Source #
Instances
| AttrInfo ActionParameterTypePropertyInfo Source # | |||||||||||||||||||||||||||||||||
Defined in GI.Gio.Interfaces.Action Associated Types
Methods attrGet :: AttrBaseTypeConstraint ActionParameterTypePropertyInfo o => o -> IO (AttrGetType ActionParameterTypePropertyInfo) # attrSet :: (AttrBaseTypeConstraint ActionParameterTypePropertyInfo o, AttrSetTypeConstraint ActionParameterTypePropertyInfo b) => o -> b -> IO () # attrClear :: AttrBaseTypeConstraint ActionParameterTypePropertyInfo o => o -> IO () # attrConstruct :: (AttrBaseTypeConstraint ActionParameterTypePropertyInfo o, AttrSetTypeConstraint ActionParameterTypePropertyInfo b) => b -> IO (GValueConstruct o) # attrTransfer :: (AttrBaseTypeConstraint ActionParameterTypePropertyInfo o, AttrTransferTypeConstraint ActionParameterTypePropertyInfo b) => Proxy o -> b -> IO (AttrTransferType ActionParameterTypePropertyInfo) # | |||||||||||||||||||||||||||||||||
| type AttrAllowedOps ActionParameterTypePropertyInfo Source # | |||||||||||||||||||||||||||||||||
Defined in GI.Gio.Interfaces.Action | |||||||||||||||||||||||||||||||||
| type AttrBaseTypeConstraint ActionParameterTypePropertyInfo Source # | |||||||||||||||||||||||||||||||||
| type AttrGetType ActionParameterTypePropertyInfo Source # | |||||||||||||||||||||||||||||||||
Defined in GI.Gio.Interfaces.Action | |||||||||||||||||||||||||||||||||
| type AttrLabel ActionParameterTypePropertyInfo Source # | |||||||||||||||||||||||||||||||||
Defined in GI.Gio.Interfaces.Action | |||||||||||||||||||||||||||||||||
| type AttrOrigin ActionParameterTypePropertyInfo Source # | |||||||||||||||||||||||||||||||||
Defined in GI.Gio.Interfaces.Action | |||||||||||||||||||||||||||||||||
| type AttrSetTypeConstraint ActionParameterTypePropertyInfo Source # | |||||||||||||||||||||||||||||||||
Defined in GI.Gio.Interfaces.Action | |||||||||||||||||||||||||||||||||
| type AttrTransferType ActionParameterTypePropertyInfo Source # | |||||||||||||||||||||||||||||||||
Defined in GI.Gio.Interfaces.Action | |||||||||||||||||||||||||||||||||
| type AttrTransferTypeConstraint ActionParameterTypePropertyInfo Source # | |||||||||||||||||||||||||||||||||
Defined in GI.Gio.Interfaces.Action | |||||||||||||||||||||||||||||||||
actionParameterType :: AttrLabelProxy "parameterType" Source #
getActionParameterType :: (MonadIO m, IsAction o) => o -> m (Maybe VariantType) Source #
Get the value of the “parameter-type” property.
When overloading is enabled, this is equivalent to
get action #parameterType
state
The state of the action, or NULL if the action is stateless.
Since: 2.28
data ActionStatePropertyInfo Source #
Instances
| AttrInfo ActionStatePropertyInfo Source # | |||||||||||||||||||||||||||||||||
Defined in GI.Gio.Interfaces.Action Associated Types
Methods attrGet :: AttrBaseTypeConstraint ActionStatePropertyInfo o => o -> IO (AttrGetType ActionStatePropertyInfo) # attrSet :: (AttrBaseTypeConstraint ActionStatePropertyInfo o, AttrSetTypeConstraint ActionStatePropertyInfo b) => o -> b -> IO () # attrClear :: AttrBaseTypeConstraint ActionStatePropertyInfo o => o -> IO () # attrConstruct :: (AttrBaseTypeConstraint ActionStatePropertyInfo o, AttrSetTypeConstraint ActionStatePropertyInfo b) => b -> IO (GValueConstruct o) # attrTransfer :: (AttrBaseTypeConstraint ActionStatePropertyInfo o, AttrTransferTypeConstraint ActionStatePropertyInfo b) => Proxy o -> b -> IO (AttrTransferType ActionStatePropertyInfo) # | |||||||||||||||||||||||||||||||||
| type AttrAllowedOps ActionStatePropertyInfo Source # | |||||||||||||||||||||||||||||||||
Defined in GI.Gio.Interfaces.Action | |||||||||||||||||||||||||||||||||
| type AttrBaseTypeConstraint ActionStatePropertyInfo Source # | |||||||||||||||||||||||||||||||||
Defined in GI.Gio.Interfaces.Action | |||||||||||||||||||||||||||||||||
| type AttrGetType ActionStatePropertyInfo Source # | |||||||||||||||||||||||||||||||||
Defined in GI.Gio.Interfaces.Action | |||||||||||||||||||||||||||||||||
| type AttrLabel ActionStatePropertyInfo Source # | |||||||||||||||||||||||||||||||||
Defined in GI.Gio.Interfaces.Action | |||||||||||||||||||||||||||||||||
| type AttrOrigin ActionStatePropertyInfo Source # | |||||||||||||||||||||||||||||||||
Defined in GI.Gio.Interfaces.Action | |||||||||||||||||||||||||||||||||
| type AttrSetTypeConstraint ActionStatePropertyInfo Source # | |||||||||||||||||||||||||||||||||
Defined in GI.Gio.Interfaces.Action | |||||||||||||||||||||||||||||||||
| type AttrTransferType ActionStatePropertyInfo Source # | |||||||||||||||||||||||||||||||||
Defined in GI.Gio.Interfaces.Action | |||||||||||||||||||||||||||||||||
| type AttrTransferTypeConstraint ActionStatePropertyInfo Source # | |||||||||||||||||||||||||||||||||
Defined in GI.Gio.Interfaces.Action | |||||||||||||||||||||||||||||||||
actionState :: AttrLabelProxy "state" Source #
getActionState :: (MonadIO m, IsAction o) => o -> m (Maybe GVariant) Source #
Get the value of the “state” property.
When overloading is enabled, this is equivalent to
get action #state
stateType
The [typegLib.VariantType] of the state that the action has, or NULL if the
action is stateless. This is immutable.
Since: 2.28
data ActionStateTypePropertyInfo Source #
Instances
| AttrInfo ActionStateTypePropertyInfo Source # | |||||||||||||||||||||||||||||||||
Defined in GI.Gio.Interfaces.Action Associated Types
Methods attrGet :: AttrBaseTypeConstraint ActionStateTypePropertyInfo o => o -> IO (AttrGetType ActionStateTypePropertyInfo) # attrSet :: (AttrBaseTypeConstraint ActionStateTypePropertyInfo o, AttrSetTypeConstraint ActionStateTypePropertyInfo b) => o -> b -> IO () # attrClear :: AttrBaseTypeConstraint ActionStateTypePropertyInfo o => o -> IO () # attrConstruct :: (AttrBaseTypeConstraint ActionStateTypePropertyInfo o, AttrSetTypeConstraint ActionStateTypePropertyInfo b) => b -> IO (GValueConstruct o) # attrTransfer :: (AttrBaseTypeConstraint ActionStateTypePropertyInfo o, AttrTransferTypeConstraint ActionStateTypePropertyInfo b) => Proxy o -> b -> IO (AttrTransferType ActionStateTypePropertyInfo) # | |||||||||||||||||||||||||||||||||
| type AttrAllowedOps ActionStateTypePropertyInfo Source # | |||||||||||||||||||||||||||||||||
Defined in GI.Gio.Interfaces.Action | |||||||||||||||||||||||||||||||||
| type AttrBaseTypeConstraint ActionStateTypePropertyInfo Source # | |||||||||||||||||||||||||||||||||
Defined in GI.Gio.Interfaces.Action | |||||||||||||||||||||||||||||||||
| type AttrGetType ActionStateTypePropertyInfo Source # | |||||||||||||||||||||||||||||||||
Defined in GI.Gio.Interfaces.Action | |||||||||||||||||||||||||||||||||
| type AttrLabel ActionStateTypePropertyInfo Source # | |||||||||||||||||||||||||||||||||
Defined in GI.Gio.Interfaces.Action | |||||||||||||||||||||||||||||||||
| type AttrOrigin ActionStateTypePropertyInfo Source # | |||||||||||||||||||||||||||||||||
Defined in GI.Gio.Interfaces.Action | |||||||||||||||||||||||||||||||||
| type AttrSetTypeConstraint ActionStateTypePropertyInfo Source # | |||||||||||||||||||||||||||||||||
Defined in GI.Gio.Interfaces.Action | |||||||||||||||||||||||||||||||||
| type AttrTransferType ActionStateTypePropertyInfo Source # | |||||||||||||||||||||||||||||||||
Defined in GI.Gio.Interfaces.Action | |||||||||||||||||||||||||||||||||
| type AttrTransferTypeConstraint ActionStateTypePropertyInfo Source # | |||||||||||||||||||||||||||||||||
Defined in GI.Gio.Interfaces.Action | |||||||||||||||||||||||||||||||||
actionStateType :: AttrLabelProxy "stateType" Source #
getActionStateType :: (MonadIO m, IsAction o) => o -> m (Maybe VariantType) Source #
Get the value of the “state-type” property.
When overloading is enabled, this is equivalent to
get action #stateType