| Copyright | Will Thompson and Iñaki García Etxebarria |
|---|---|
| License | LGPL-2.1 |
| Maintainer | Iñaki García Etxebarria |
| Safe Haskell | None |
| Language | Haskell2010 |
GI.Gio.Interfaces.DBusObjectManager
Description
The GDBusObjectManager type is the base type for service- and
client-side implementations of the standardized
`org.freedesktop.DBus.ObjectManager`
interface.
See DBusObjectManagerClient for the client-side implementation
and DBusObjectManagerServer for the service-side implementation.
Synopsis
- newtype DBusObjectManager = DBusObjectManager (ManagedPtr DBusObjectManager)
- class (GObject o, IsDescendantOf DBusObjectManager o) => IsDBusObjectManager o
- toDBusObjectManager :: (MonadIO m, IsDBusObjectManager o) => o -> m DBusObjectManager
- type family ResolveDBusObjectManagerMethod (t :: Symbol) o where ...
- data DBusObjectManagerGetInterfaceMethodInfo
- dBusObjectManagerGetInterface :: (HasCallStack, MonadIO m, IsDBusObjectManager a) => a -> Text -> Text -> m (Maybe DBusInterface)
- data DBusObjectManagerGetObjectMethodInfo
- dBusObjectManagerGetObject :: (HasCallStack, MonadIO m, IsDBusObjectManager a) => a -> Text -> m (Maybe DBusObject)
- data DBusObjectManagerGetObjectPathMethodInfo
- dBusObjectManagerGetObjectPath :: (HasCallStack, MonadIO m, IsDBusObjectManager a) => a -> m Text
- data DBusObjectManagerGetObjectsMethodInfo
- dBusObjectManagerGetObjects :: (HasCallStack, MonadIO m, IsDBusObjectManager a) => a -> m [DBusObject]
- type DBusObjectManagerInterfaceAddedCallback = DBusObject -> DBusInterface -> IO ()
- data DBusObjectManagerInterfaceAddedSignalInfo
- afterDBusObjectManagerInterfaceAdded :: (IsDBusObjectManager a, MonadIO m) => a -> ((?self :: a) => DBusObjectManagerInterfaceAddedCallback) -> m SignalHandlerId
- onDBusObjectManagerInterfaceAdded :: (IsDBusObjectManager a, MonadIO m) => a -> ((?self :: a) => DBusObjectManagerInterfaceAddedCallback) -> m SignalHandlerId
- type DBusObjectManagerInterfaceRemovedCallback = DBusObject -> DBusInterface -> IO ()
- data DBusObjectManagerInterfaceRemovedSignalInfo
- afterDBusObjectManagerInterfaceRemoved :: (IsDBusObjectManager a, MonadIO m) => a -> ((?self :: a) => DBusObjectManagerInterfaceRemovedCallback) -> m SignalHandlerId
- onDBusObjectManagerInterfaceRemoved :: (IsDBusObjectManager a, MonadIO m) => a -> ((?self :: a) => DBusObjectManagerInterfaceRemovedCallback) -> m SignalHandlerId
- type DBusObjectManagerObjectAddedCallback = DBusObject -> IO ()
- data DBusObjectManagerObjectAddedSignalInfo
- afterDBusObjectManagerObjectAdded :: (IsDBusObjectManager a, MonadIO m) => a -> ((?self :: a) => DBusObjectManagerObjectAddedCallback) -> m SignalHandlerId
- onDBusObjectManagerObjectAdded :: (IsDBusObjectManager a, MonadIO m) => a -> ((?self :: a) => DBusObjectManagerObjectAddedCallback) -> m SignalHandlerId
- type DBusObjectManagerObjectRemovedCallback = DBusObject -> IO ()
- data DBusObjectManagerObjectRemovedSignalInfo
- afterDBusObjectManagerObjectRemoved :: (IsDBusObjectManager a, MonadIO m) => a -> ((?self :: a) => DBusObjectManagerObjectRemovedCallback) -> m SignalHandlerId
- onDBusObjectManagerObjectRemoved :: (IsDBusObjectManager a, MonadIO m) => a -> ((?self :: a) => DBusObjectManagerObjectRemovedCallback) -> m SignalHandlerId
Exported types
newtype DBusObjectManager Source #
Memory-managed wrapper type.
Constructors
| DBusObjectManager (ManagedPtr DBusObjectManager) |
Instances
class (GObject o, IsDescendantOf DBusObjectManager o) => IsDBusObjectManager o Source #
Type class for types which can be safely cast to DBusObjectManager, for instance with toDBusObjectManager.
Instances
| (GObject o, IsDescendantOf DBusObjectManager o) => IsDBusObjectManager o Source # | |
Defined in GI.Gio.Interfaces.DBusObjectManager | |
toDBusObjectManager :: (MonadIO m, IsDBusObjectManager o) => o -> m DBusObjectManager Source #
Cast to DBusObjectManager, for types for which this is known to be safe. For general casts, use castTo.
Methods
Click to display all available methods, including inherited ones
Methods
bindProperty, bindPropertyFull, forceFloating, freezeNotify, getv, isFloating, notify, notifyByPspec, ref, refSink, runDispose, stealData, stealQdata, thawNotify, unref, watchClosure.
Getters
getData, getInterface, getObject, getObjectPath, getObjects, getProperty, getQdata.
Setters
type family ResolveDBusObjectManagerMethod (t :: Symbol) o where ... Source #
Equations
getInterface
data DBusObjectManagerGetInterfaceMethodInfo Source #
Instances
| (signature ~ (Text -> Text -> m (Maybe DBusInterface)), MonadIO m, IsDBusObjectManager a) => OverloadedMethod DBusObjectManagerGetInterfaceMethodInfo a signature Source # | |
Defined in GI.Gio.Interfaces.DBusObjectManager Methods overloadedMethod :: a -> signature # | |
| OverloadedMethodInfo DBusObjectManagerGetInterfaceMethodInfo (a :: Type) Source # | |
Defined in GI.Gio.Interfaces.DBusObjectManager Methods | |
dBusObjectManagerGetInterface Source #
Arguments
| :: (HasCallStack, MonadIO m, IsDBusObjectManager a) | |
| => a |
|
| -> Text |
|
| -> Text |
|
| -> m (Maybe DBusInterface) | Returns: A |
Gets the interface proxy for interfaceName at objectPath, if
any.
Since: 2.30
getObject
data DBusObjectManagerGetObjectMethodInfo Source #
Instances
| (signature ~ (Text -> m (Maybe DBusObject)), MonadIO m, IsDBusObjectManager a) => OverloadedMethod DBusObjectManagerGetObjectMethodInfo a signature Source # | |
Defined in GI.Gio.Interfaces.DBusObjectManager Methods overloadedMethod :: a -> signature # | |
| OverloadedMethodInfo DBusObjectManagerGetObjectMethodInfo (a :: Type) Source # | |
Defined in GI.Gio.Interfaces.DBusObjectManager Methods | |
dBusObjectManagerGetObject Source #
Arguments
| :: (HasCallStack, MonadIO m, IsDBusObjectManager a) | |
| => a |
|
| -> Text |
|
| -> m (Maybe DBusObject) | Returns: A |
Gets the DBusObject at objectPath, if any.
Since: 2.30
getObjectPath
data DBusObjectManagerGetObjectPathMethodInfo Source #
Instances
| (signature ~ m Text, MonadIO m, IsDBusObjectManager a) => OverloadedMethod DBusObjectManagerGetObjectPathMethodInfo a signature Source # | |
Defined in GI.Gio.Interfaces.DBusObjectManager Methods overloadedMethod :: a -> signature # | |
| OverloadedMethodInfo DBusObjectManagerGetObjectPathMethodInfo (a :: Type) Source # | |
Defined in GI.Gio.Interfaces.DBusObjectManager Methods | |
dBusObjectManagerGetObjectPath Source #
Arguments
| :: (HasCallStack, MonadIO m, IsDBusObjectManager a) | |
| => a |
|
| -> m Text | Returns: A string owned by |
Gets the object path that manager is for.
Since: 2.30
getObjects
data DBusObjectManagerGetObjectsMethodInfo Source #
Instances
| (signature ~ m [DBusObject], MonadIO m, IsDBusObjectManager a) => OverloadedMethod DBusObjectManagerGetObjectsMethodInfo a signature Source # | |
Defined in GI.Gio.Interfaces.DBusObjectManager Methods overloadedMethod :: a -> signature # | |
| OverloadedMethodInfo DBusObjectManagerGetObjectsMethodInfo (a :: Type) Source # | |
Defined in GI.Gio.Interfaces.DBusObjectManager Methods | |
dBusObjectManagerGetObjects Source #
Arguments
| :: (HasCallStack, MonadIO m, IsDBusObjectManager a) | |
| => a |
|
| -> m [DBusObject] | Returns: A list of
|
Gets all DBusObject objects known to manager.
Since: 2.30
Signals
interfaceAdded
type DBusObjectManagerInterfaceAddedCallback Source #
Arguments
| = DBusObject |
|
| -> DBusInterface |
|
| -> IO () |
Emitted when interface is added to object.
This signal exists purely as a convenience to avoid having to
connect signals to all objects managed by manager.
Since: 2.30
data DBusObjectManagerInterfaceAddedSignalInfo Source #
Instances
| SignalInfo DBusObjectManagerInterfaceAddedSignalInfo Source # | |||||
Defined in GI.Gio.Interfaces.DBusObjectManager Associated Types
Methods connectSignal :: GObject o => o -> (o -> HaskellCallbackType DBusObjectManagerInterfaceAddedSignalInfo) -> SignalConnectMode -> Maybe Text -> IO SignalHandlerId # | |||||
| type HaskellCallbackType DBusObjectManagerInterfaceAddedSignalInfo Source # | |||||
afterDBusObjectManagerInterfaceAdded :: (IsDBusObjectManager a, MonadIO m) => a -> ((?self :: a) => DBusObjectManagerInterfaceAddedCallback) -> m SignalHandlerId Source #
Connect a signal handler for the interfaceAdded signal, to be run after the default handler. When overloading is enabled, this is equivalent to
after dBusObjectManager #interfaceAdded callback
By default the object invoking the signal is not passed to the callback.
If you need to access it, you can use the implit ?self parameter.
Note that this requires activating the ImplicitParams GHC extension.
onDBusObjectManagerInterfaceAdded :: (IsDBusObjectManager a, MonadIO m) => a -> ((?self :: a) => DBusObjectManagerInterfaceAddedCallback) -> m SignalHandlerId Source #
Connect a signal handler for the interfaceAdded signal, to be run before the default handler. When overloading is enabled, this is equivalent to
on dBusObjectManager #interfaceAdded callback
interfaceRemoved
type DBusObjectManagerInterfaceRemovedCallback Source #
Arguments
| = DBusObject |
|
| -> DBusInterface |
|
| -> IO () |
Emitted when interface has been removed from object.
This signal exists purely as a convenience to avoid having to
connect signals to all objects managed by manager.
Since: 2.30
data DBusObjectManagerInterfaceRemovedSignalInfo Source #
Instances
| SignalInfo DBusObjectManagerInterfaceRemovedSignalInfo Source # | |||||
Defined in GI.Gio.Interfaces.DBusObjectManager Associated Types
Methods connectSignal :: GObject o => o -> (o -> HaskellCallbackType DBusObjectManagerInterfaceRemovedSignalInfo) -> SignalConnectMode -> Maybe Text -> IO SignalHandlerId # | |||||
| type HaskellCallbackType DBusObjectManagerInterfaceRemovedSignalInfo Source # | |||||
afterDBusObjectManagerInterfaceRemoved :: (IsDBusObjectManager a, MonadIO m) => a -> ((?self :: a) => DBusObjectManagerInterfaceRemovedCallback) -> m SignalHandlerId Source #
Connect a signal handler for the interfaceRemoved signal, to be run after the default handler. When overloading is enabled, this is equivalent to
after dBusObjectManager #interfaceRemoved callback
By default the object invoking the signal is not passed to the callback.
If you need to access it, you can use the implit ?self parameter.
Note that this requires activating the ImplicitParams GHC extension.
onDBusObjectManagerInterfaceRemoved :: (IsDBusObjectManager a, MonadIO m) => a -> ((?self :: a) => DBusObjectManagerInterfaceRemovedCallback) -> m SignalHandlerId Source #
Connect a signal handler for the interfaceRemoved signal, to be run before the default handler. When overloading is enabled, this is equivalent to
on dBusObjectManager #interfaceRemoved callback
objectAdded
type DBusObjectManagerObjectAddedCallback Source #
Arguments
| = DBusObject |
|
| -> IO () |
Emitted when object is added to manager.
Since: 2.30
data DBusObjectManagerObjectAddedSignalInfo Source #
Instances
| SignalInfo DBusObjectManagerObjectAddedSignalInfo Source # | |||||
Defined in GI.Gio.Interfaces.DBusObjectManager Associated Types
Methods connectSignal :: GObject o => o -> (o -> HaskellCallbackType DBusObjectManagerObjectAddedSignalInfo) -> SignalConnectMode -> Maybe Text -> IO SignalHandlerId # | |||||
| type HaskellCallbackType DBusObjectManagerObjectAddedSignalInfo Source # | |||||
afterDBusObjectManagerObjectAdded :: (IsDBusObjectManager a, MonadIO m) => a -> ((?self :: a) => DBusObjectManagerObjectAddedCallback) -> m SignalHandlerId Source #
Connect a signal handler for the objectAdded signal, to be run after the default handler. When overloading is enabled, this is equivalent to
after dBusObjectManager #objectAdded callback
By default the object invoking the signal is not passed to the callback.
If you need to access it, you can use the implit ?self parameter.
Note that this requires activating the ImplicitParams GHC extension.
onDBusObjectManagerObjectAdded :: (IsDBusObjectManager a, MonadIO m) => a -> ((?self :: a) => DBusObjectManagerObjectAddedCallback) -> m SignalHandlerId Source #
Connect a signal handler for the objectAdded signal, to be run before the default handler. When overloading is enabled, this is equivalent to
on dBusObjectManager #objectAdded callback
objectRemoved
type DBusObjectManagerObjectRemovedCallback Source #
Arguments
| = DBusObject |
|
| -> IO () |
Emitted when object is removed from manager.
Since: 2.30
data DBusObjectManagerObjectRemovedSignalInfo Source #
Instances
| SignalInfo DBusObjectManagerObjectRemovedSignalInfo Source # | |||||
Defined in GI.Gio.Interfaces.DBusObjectManager Associated Types
Methods connectSignal :: GObject o => o -> (o -> HaskellCallbackType DBusObjectManagerObjectRemovedSignalInfo) -> SignalConnectMode -> Maybe Text -> IO SignalHandlerId # | |||||
| type HaskellCallbackType DBusObjectManagerObjectRemovedSignalInfo Source # | |||||
afterDBusObjectManagerObjectRemoved :: (IsDBusObjectManager a, MonadIO m) => a -> ((?self :: a) => DBusObjectManagerObjectRemovedCallback) -> m SignalHandlerId Source #
Connect a signal handler for the objectRemoved signal, to be run after the default handler. When overloading is enabled, this is equivalent to
after dBusObjectManager #objectRemoved callback
By default the object invoking the signal is not passed to the callback.
If you need to access it, you can use the implit ?self parameter.
Note that this requires activating the ImplicitParams GHC extension.
onDBusObjectManagerObjectRemoved :: (IsDBusObjectManager a, MonadIO m) => a -> ((?self :: a) => DBusObjectManagerObjectRemovedCallback) -> m SignalHandlerId Source #
Connect a signal handler for the objectRemoved signal, to be run before the default handler. When overloading is enabled, this is equivalent to
on dBusObjectManager #objectRemoved callback