| Copyright | Will Thompson and Iñaki García Etxebarria |
|---|---|
| License | LGPL-2.1 |
| Maintainer | Iñaki García Etxebarria |
| Safe Haskell | None |
| Language | Haskell2010 |
GI.Gio.Interfaces.TlsServerConnection
Description
GTlsServerConnection is the server-side subclass of
TlsConnection, representing a server-side TLS connection.
Since: 2.28
Synopsis
- newtype TlsServerConnection = TlsServerConnection (ManagedPtr TlsServerConnection)
- class (GObject o, IsDescendantOf TlsServerConnection o) => IsTlsServerConnection o
- toTlsServerConnection :: (MonadIO m, IsTlsServerConnection o) => o -> m TlsServerConnection
- type family ResolveTlsServerConnectionMethod (t :: Symbol) o where ...
- tlsServerConnectionNew :: (HasCallStack, MonadIO m, IsIOStream a, IsTlsCertificate b) => a -> Maybe b -> m TlsServerConnection
- data TlsServerConnectionAuthenticationModePropertyInfo
- constructTlsServerConnectionAuthenticationMode :: (IsTlsServerConnection o, MonadIO m) => TlsAuthenticationMode -> m (GValueConstruct o)
- getTlsServerConnectionAuthenticationMode :: (MonadIO m, IsTlsServerConnection o) => o -> m TlsAuthenticationMode
- setTlsServerConnectionAuthenticationMode :: (MonadIO m, IsTlsServerConnection o) => o -> TlsAuthenticationMode -> m ()
- tlsServerConnectionAuthenticationMode :: AttrLabelProxy "authenticationMode"
Exported types
newtype TlsServerConnection Source #
Memory-managed wrapper type.
Constructors
| TlsServerConnection (ManagedPtr TlsServerConnection) |
Instances
class (GObject o, IsDescendantOf TlsServerConnection o) => IsTlsServerConnection o Source #
Type class for types which can be safely cast to TlsServerConnection, for instance with toTlsServerConnection.
Instances
| (GObject o, IsDescendantOf TlsServerConnection o) => IsTlsServerConnection o Source # | |
Defined in GI.Gio.Interfaces.TlsServerConnection | |
toTlsServerConnection :: (MonadIO m, IsTlsServerConnection o) => o -> m TlsServerConnection Source #
Cast to TlsServerConnection, for types for which this is known to be safe. For general casts, use castTo.
Methods
Click to display all available methods, including inherited ones
Methods
bindProperty, bindPropertyFull, clearPending, close, closeAsync, closeFinish, emitAcceptCertificate, forceFloating, freezeNotify, getv, handshake, handshakeAsync, handshakeFinish, hasPending, isClosed, isFloating, notify, notifyByPspec, ref, refSink, runDispose, spliceAsync, stealData, stealQdata, thawNotify, unref, watchClosure.
Getters
getCertificate, getChannelBindingData, getCiphersuiteName, getData, getDatabase, getInputStream, getInteraction, getNegotiatedProtocol, getOutputStream, getPeerCertificate, getPeerCertificateErrors, getProperty, getProtocolVersion, getQdata, getRehandshakeMode, getRequireCloseNotify, getUseSystemCertdb.
Setters
setAdvertisedProtocols, setCertificate, setData, setDataFull, setDatabase, setInteraction, setPending, setProperty, setRehandshakeMode, setRequireCloseNotify, setUseSystemCertdb.
type family ResolveTlsServerConnectionMethod (t :: Symbol) o where ... Source #
Equations
new
tlsServerConnectionNew Source #
Arguments
| :: (HasCallStack, MonadIO m, IsIOStream a, IsTlsCertificate b) | |
| => a |
|
| -> Maybe b |
|
| -> m TlsServerConnection | Returns: the new
|
Creates a new TlsServerConnection wrapping baseIoStream (which
must have pollable input and output streams).
See the documentation for TlsConnection:baseIoStream for restrictions
on when application code can run operations on the baseIoStream after
this function has returned.
Since: 2.28
Properties
authenticationMode
The TlsAuthenticationMode for the server. This can be changed
before calling tlsConnectionHandshake if you want to
rehandshake with a different mode from the initial handshake.
Since: 2.28
data TlsServerConnectionAuthenticationModePropertyInfo Source #
Instances
constructTlsServerConnectionAuthenticationMode :: (IsTlsServerConnection o, MonadIO m) => TlsAuthenticationMode -> m (GValueConstruct o) Source #
Construct a GValueConstruct with valid value for the “authentication-mode” property. This is rarely needed directly, but it is used by new.
getTlsServerConnectionAuthenticationMode :: (MonadIO m, IsTlsServerConnection o) => o -> m TlsAuthenticationMode Source #
Get the value of the “authentication-mode” property.
When overloading is enabled, this is equivalent to
get tlsServerConnection #authenticationMode
setTlsServerConnectionAuthenticationMode :: (MonadIO m, IsTlsServerConnection o) => o -> TlsAuthenticationMode -> m () Source #
Set the value of the “authentication-mode” property.
When overloading is enabled, this is equivalent to
settlsServerConnection [ #authenticationMode:=value ]
tlsServerConnectionAuthenticationMode :: AttrLabelProxy "authenticationMode" Source #