| Copyright | Will Thompson and Iñaki García Etxebarria |
|---|---|
| License | LGPL-2.1 |
| Maintainer | Iñaki García Etxebarria |
| Safe Haskell | None |
| Language | Haskell2010 |
GI.Gio.Interfaces.Volume
Description
The GVolume interface represents user-visible objects that can be
mounted. For example, a file system partition on a USB flash drive, or an
optical disc inserted into a disc drive.
If a GVolume is currently mounted, the corresponding Mount can
be retrieved using volumeGetMount.
Mounting a GVolume instance is an asynchronous operation. For more
information about asynchronous operations, see AsyncResult and
Task. To mount a GVolume, first call volumeMount
with (at least) the GVolume instance, optionally a
MountOperation object and a [typegio.AsyncReadyCallback].
Typically, one will only want to pass NULL for the
MountOperation if automounting all volumes when a desktop session
starts since it’s not desirable to put up a lot of dialogs asking
for credentials.
The callback will be fired when the operation has resolved (either
with success or failure), and a AsyncResult instance will be
passed to the callback. That callback should then call
volumeMountFinish with the GVolume instance and the
AsyncResult data to see if the operation was completed
successfully. If a [typegLib.Error] is present when
volumeMountFinish is called, then it will be filled with any
error information.
Note, when porting from GnomeVFS,
GVolume is the moral equivalent of GnomeVFSDrive.
Volume Identifiers
It is sometimes necessary to directly access the underlying
operating system object behind a volume (e.g. for passing a volume
to an application via the command line). For this purpose, GIO
allows to obtain an ‘identifier’ for the volume. There can be
different kinds of identifiers, such as Hal UDIs, filesystem labels,
traditional Unix devices (e.g. /dev/sda2), UUIDs. GIO uses predefined
strings as names for the different kinds of identifiers:
G_VOLUME_IDENTIFIER_KIND_UUID, G_VOLUME_IDENTIFIER_KIND_LABEL, etc.
Use volumeGetIdentifier to obtain an identifier for a volume.
Note that G_VOLUME_IDENTIFIER_KIND_HAL_UDI will only be available
when the GVFS hal volume monitor is in use. Other volume monitors
will generally be able to provide the G_VOLUME_IDENTIFIER_KIND_UNIX_DEVICE
identifier, which can be used to obtain a hal device by means of
libhal_manager_find_device_string_match().
Synopsis
- newtype Volume = Volume (ManagedPtr Volume)
- class (GObject o, IsDescendantOf Volume o) => IsVolume o
- toVolume :: (MonadIO m, IsVolume o) => o -> m Volume
- type family ResolveVolumeMethod (t :: Symbol) o where ...
- data VolumeCanEjectMethodInfo
- volumeCanEject :: (HasCallStack, MonadIO m, IsVolume a) => a -> m Bool
- data VolumeCanMountMethodInfo
- volumeCanMount :: (HasCallStack, MonadIO m, IsVolume a) => a -> m Bool
- data VolumeEjectMethodInfo
- volumeEject :: (HasCallStack, MonadIO m, IsVolume a, IsCancellable b) => a -> [MountUnmountFlags] -> Maybe b -> Maybe AsyncReadyCallback -> m ()
- data VolumeEjectFinishMethodInfo
- volumeEjectFinish :: (HasCallStack, MonadIO m, IsVolume a, IsAsyncResult b) => a -> b -> m ()
- data VolumeEjectWithOperationMethodInfo
- volumeEjectWithOperation :: (HasCallStack, MonadIO m, IsVolume a, IsMountOperation b, IsCancellable c) => a -> [MountUnmountFlags] -> Maybe b -> Maybe c -> Maybe AsyncReadyCallback -> m ()
- data VolumeEjectWithOperationFinishMethodInfo
- volumeEjectWithOperationFinish :: (HasCallStack, MonadIO m, IsVolume a, IsAsyncResult b) => a -> b -> m ()
- data VolumeEnumerateIdentifiersMethodInfo
- volumeEnumerateIdentifiers :: (HasCallStack, MonadIO m, IsVolume a) => a -> m [Text]
- data VolumeGetActivationRootMethodInfo
- volumeGetActivationRoot :: (HasCallStack, MonadIO m, IsVolume a) => a -> m (Maybe File)
- data VolumeGetDriveMethodInfo
- volumeGetDrive :: (HasCallStack, MonadIO m, IsVolume a) => a -> m (Maybe Drive)
- data VolumeGetIconMethodInfo
- volumeGetIcon :: (HasCallStack, MonadIO m, IsVolume a) => a -> m Icon
- data VolumeGetIdentifierMethodInfo
- volumeGetIdentifier :: (HasCallStack, MonadIO m, IsVolume a) => a -> Text -> m (Maybe Text)
- data VolumeGetMountMethodInfo
- volumeGetMount :: (HasCallStack, MonadIO m, IsVolume a) => a -> m (Maybe Mount)
- data VolumeGetNameMethodInfo
- volumeGetName :: (HasCallStack, MonadIO m, IsVolume a) => a -> m Text
- data VolumeGetSortKeyMethodInfo
- volumeGetSortKey :: (HasCallStack, MonadIO m, IsVolume a) => a -> m (Maybe Text)
- data VolumeGetSymbolicIconMethodInfo
- volumeGetSymbolicIcon :: (HasCallStack, MonadIO m, IsVolume a) => a -> m Icon
- data VolumeGetUuidMethodInfo
- volumeGetUuid :: (HasCallStack, MonadIO m, IsVolume a) => a -> m (Maybe Text)
- data VolumeMountMethodInfo
- volumeMount :: (HasCallStack, MonadIO m, IsVolume a, IsMountOperation b, IsCancellable c) => a -> [MountMountFlags] -> Maybe b -> Maybe c -> Maybe AsyncReadyCallback -> m ()
- data VolumeMountFinishMethodInfo
- volumeMountFinish :: (HasCallStack, MonadIO m, IsVolume a, IsAsyncResult b) => a -> b -> m ()
- data VolumeShouldAutomountMethodInfo
- volumeShouldAutomount :: (HasCallStack, MonadIO m, IsVolume a) => a -> m Bool
- type VolumeChangedCallback = IO ()
- data VolumeChangedSignalInfo
- afterVolumeChanged :: (IsVolume a, MonadIO m) => a -> ((?self :: a) => VolumeChangedCallback) -> m SignalHandlerId
- onVolumeChanged :: (IsVolume a, MonadIO m) => a -> ((?self :: a) => VolumeChangedCallback) -> m SignalHandlerId
- type VolumeRemovedCallback = IO ()
- data VolumeRemovedSignalInfo
- afterVolumeRemoved :: (IsVolume a, MonadIO m) => a -> ((?self :: a) => VolumeRemovedCallback) -> m SignalHandlerId
- onVolumeRemoved :: (IsVolume a, MonadIO m) => a -> ((?self :: a) => VolumeRemovedCallback) -> m SignalHandlerId
Exported types
Memory-managed wrapper type.
Constructors
| Volume (ManagedPtr Volume) |
Instances
class (GObject o, IsDescendantOf Volume o) => IsVolume o Source #
Instances
| (GObject o, IsDescendantOf Volume o) => IsVolume o Source # | |
Defined in GI.Gio.Interfaces.Volume | |
Methods
Click to display all available methods, including inherited ones
Methods
bindProperty, bindPropertyFull, canEject, canMount, eject, ejectFinish, ejectWithOperation, ejectWithOperationFinish, enumerateIdentifiers, forceFloating, freezeNotify, getv, isFloating, mount, mountFinish, notify, notifyByPspec, ref, refSink, runDispose, shouldAutomount, stealData, stealQdata, thawNotify, unref, watchClosure.
Getters
getActivationRoot, getData, getDrive, getIcon, getIdentifier, getMount, getName, getProperty, getQdata, getSortKey, getSymbolicIcon, getUuid.
Setters
type family ResolveVolumeMethod (t :: Symbol) o where ... Source #
Equations
canEject
data VolumeCanEjectMethodInfo Source #
Instances
| (signature ~ m Bool, MonadIO m, IsVolume a) => OverloadedMethod VolumeCanEjectMethodInfo a signature Source # | |
Defined in GI.Gio.Interfaces.Volume Methods overloadedMethod :: a -> signature # | |
| OverloadedMethodInfo VolumeCanEjectMethodInfo (a :: Type) Source # | |
Defined in GI.Gio.Interfaces.Volume Methods | |
Arguments
| :: (HasCallStack, MonadIO m, IsVolume a) | |
| => a |
|
| -> m Bool |
Checks if a volume can be ejected.
canMount
data VolumeCanMountMethodInfo Source #
Instances
| (signature ~ m Bool, MonadIO m, IsVolume a) => OverloadedMethod VolumeCanMountMethodInfo a signature Source # | |
Defined in GI.Gio.Interfaces.Volume Methods overloadedMethod :: a -> signature # | |
| OverloadedMethodInfo VolumeCanMountMethodInfo (a :: Type) Source # | |
Defined in GI.Gio.Interfaces.Volume Methods | |
Arguments
| :: (HasCallStack, MonadIO m, IsVolume a) | |
| => a |
|
| -> m Bool |
Checks if a volume can be mounted.
eject
data VolumeEjectMethodInfo Source #
Instances
| (signature ~ ([MountUnmountFlags] -> Maybe b -> Maybe AsyncReadyCallback -> m ()), MonadIO m, IsVolume a, IsCancellable b) => OverloadedMethod VolumeEjectMethodInfo a signature Source # | |
Defined in GI.Gio.Interfaces.Volume Methods overloadedMethod :: a -> signature # | |
| OverloadedMethodInfo VolumeEjectMethodInfo (a :: Type) Source # | |
Defined in GI.Gio.Interfaces.Volume Methods | |
Arguments
| :: (HasCallStack, MonadIO m, IsVolume a, IsCancellable b) | |
| => a |
|
| -> [MountUnmountFlags] |
|
| -> Maybe b |
|
| -> Maybe AsyncReadyCallback |
|
| -> m () |
Deprecated: (Since version 2.22)Use volumeEjectWithOperation instead.
Ejects a volume. This is an asynchronous operation, and is
finished by calling volumeEjectFinish with the volume
and AsyncResult returned in the callback.
ejectFinish
data VolumeEjectFinishMethodInfo Source #
Instances
| (signature ~ (b -> m ()), MonadIO m, IsVolume a, IsAsyncResult b) => OverloadedMethod VolumeEjectFinishMethodInfo a signature Source # | |
Defined in GI.Gio.Interfaces.Volume Methods overloadedMethod :: a -> signature # | |
| OverloadedMethodInfo VolumeEjectFinishMethodInfo (a :: Type) Source # | |
Defined in GI.Gio.Interfaces.Volume Methods | |
Arguments
| :: (HasCallStack, MonadIO m, IsVolume a, IsAsyncResult b) | |
| => a |
|
| -> b |
|
| -> m () | (Can throw |
Deprecated: (Since version 2.22)Use volumeEjectWithOperationFinish instead.
Finishes ejecting a volume. If any errors occurred during the operation,
error will be set to contain the errors and False will be returned.
ejectWithOperation
data VolumeEjectWithOperationMethodInfo Source #
Instances
| (signature ~ ([MountUnmountFlags] -> Maybe b -> Maybe c -> Maybe AsyncReadyCallback -> m ()), MonadIO m, IsVolume a, IsMountOperation b, IsCancellable c) => OverloadedMethod VolumeEjectWithOperationMethodInfo a signature Source # | |
Defined in GI.Gio.Interfaces.Volume Methods overloadedMethod :: a -> signature # | |
| OverloadedMethodInfo VolumeEjectWithOperationMethodInfo (a :: Type) Source # | |
Defined in GI.Gio.Interfaces.Volume Methods | |
volumeEjectWithOperation Source #
Arguments
| :: (HasCallStack, MonadIO m, IsVolume a, IsMountOperation b, IsCancellable c) | |
| => a |
|
| -> [MountUnmountFlags] |
|
| -> Maybe b |
|
| -> Maybe c |
|
| -> Maybe AsyncReadyCallback |
|
| -> m () |
Ejects a volume. This is an asynchronous operation, and is
finished by calling volumeEjectWithOperationFinish with the volume
and AsyncResult data returned in the callback.
Since: 2.22
ejectWithOperationFinish
data VolumeEjectWithOperationFinishMethodInfo Source #
Instances
| (signature ~ (b -> m ()), MonadIO m, IsVolume a, IsAsyncResult b) => OverloadedMethod VolumeEjectWithOperationFinishMethodInfo a signature Source # | |
Defined in GI.Gio.Interfaces.Volume Methods overloadedMethod :: a -> signature # | |
| OverloadedMethodInfo VolumeEjectWithOperationFinishMethodInfo (a :: Type) Source # | |
Defined in GI.Gio.Interfaces.Volume Methods | |
volumeEjectWithOperationFinish Source #
Arguments
| :: (HasCallStack, MonadIO m, IsVolume a, IsAsyncResult b) | |
| => a |
|
| -> b |
|
| -> m () | (Can throw |
Finishes ejecting a volume. If any errors occurred during the operation,
error will be set to contain the errors and False will be returned.
Since: 2.22
enumerateIdentifiers
data VolumeEnumerateIdentifiersMethodInfo Source #
Instances
| (signature ~ m [Text], MonadIO m, IsVolume a) => OverloadedMethod VolumeEnumerateIdentifiersMethodInfo a signature Source # | |
Defined in GI.Gio.Interfaces.Volume Methods overloadedMethod :: a -> signature # | |
| OverloadedMethodInfo VolumeEnumerateIdentifiersMethodInfo (a :: Type) Source # | |
Defined in GI.Gio.Interfaces.Volume Methods | |
volumeEnumerateIdentifiers Source #
Arguments
| :: (HasCallStack, MonadIO m, IsVolume a) | |
| => a |
|
| -> m [Text] | Returns: a |
Gets the kinds of identifiers that volume has.
Use volumeGetIdentifier to obtain the identifiers themselves.
getActivationRoot
data VolumeGetActivationRootMethodInfo Source #
Instances
| (signature ~ m (Maybe File), MonadIO m, IsVolume a) => OverloadedMethod VolumeGetActivationRootMethodInfo a signature Source # | |
Defined in GI.Gio.Interfaces.Volume Methods overloadedMethod :: a -> signature # | |
| OverloadedMethodInfo VolumeGetActivationRootMethodInfo (a :: Type) Source # | |
Defined in GI.Gio.Interfaces.Volume Methods | |
volumeGetActivationRoot Source #
Arguments
| :: (HasCallStack, MonadIO m, IsVolume a) | |
| => a |
|
| -> m (Maybe File) | Returns: the activation root of |
Gets the activation root for a Volume if it is known ahead of
mount time. Returns Nothing otherwise. If not Nothing and if volume
is mounted, then the result of mountGetRoot on the
Mount object obtained from volumeGetMount will always
either be equal or a prefix of what this function returns. In
other words, in code
C code
GMount *mount; GFile *mount_root GFile *volume_activation_root; mount = g_volume_get_mount (volume); // mounted, so never NULL mount_root = g_mount_get_root (mount); volume_activation_root = g_volume_get_activation_root (volume); // assume not NULL
then the expression
C code
(g_file_has_prefix (volume_activation_root, mount_root) || g_file_equal (volume_activation_root, mount_root))
will always be True.
Activation roots are typically used in VolumeMonitor
implementations to find the underlying mount to shadow, see
mountIsShadowed for more details.
Since: 2.18
getDrive
data VolumeGetDriveMethodInfo Source #
Instances
| (signature ~ m (Maybe Drive), MonadIO m, IsVolume a) => OverloadedMethod VolumeGetDriveMethodInfo a signature Source # | |
Defined in GI.Gio.Interfaces.Volume Methods overloadedMethod :: a -> signature # | |
| OverloadedMethodInfo VolumeGetDriveMethodInfo (a :: Type) Source # | |
Defined in GI.Gio.Interfaces.Volume Methods | |
Arguments
| :: (HasCallStack, MonadIO m, IsVolume a) | |
| => a |
|
| -> m (Maybe Drive) | Returns: a |
Gets the drive for the volume.
getIcon
data VolumeGetIconMethodInfo Source #
Instances
| (signature ~ m Icon, MonadIO m, IsVolume a) => OverloadedMethod VolumeGetIconMethodInfo a signature Source # | |
Defined in GI.Gio.Interfaces.Volume Methods overloadedMethod :: a -> signature # | |
| OverloadedMethodInfo VolumeGetIconMethodInfo (a :: Type) Source # | |
Defined in GI.Gio.Interfaces.Volume Methods | |
Arguments
| :: (HasCallStack, MonadIO m, IsVolume a) | |
| => a |
|
| -> m Icon | Returns: a |
Gets the icon for volume.
getIdentifier
data VolumeGetIdentifierMethodInfo Source #
Instances
| (signature ~ (Text -> m (Maybe Text)), MonadIO m, IsVolume a) => OverloadedMethod VolumeGetIdentifierMethodInfo a signature Source # | |
Defined in GI.Gio.Interfaces.Volume Methods overloadedMethod :: a -> signature # | |
| OverloadedMethodInfo VolumeGetIdentifierMethodInfo (a :: Type) Source # | |
Defined in GI.Gio.Interfaces.Volume Methods | |
Arguments
| :: (HasCallStack, MonadIO m, IsVolume a) | |
| => a |
|
| -> Text |
|
| -> m (Maybe Text) | Returns: a newly allocated string containing the
requested identifier, or |
Gets the identifier of the given kind for volume.
See the introduction for more
information about volume identifiers.
getMount
data VolumeGetMountMethodInfo Source #
Instances
| (signature ~ m (Maybe Mount), MonadIO m, IsVolume a) => OverloadedMethod VolumeGetMountMethodInfo a signature Source # | |
Defined in GI.Gio.Interfaces.Volume Methods overloadedMethod :: a -> signature # | |
| OverloadedMethodInfo VolumeGetMountMethodInfo (a :: Type) Source # | |
Defined in GI.Gio.Interfaces.Volume Methods | |
Arguments
| :: (HasCallStack, MonadIO m, IsVolume a) | |
| => a |
|
| -> m (Maybe Mount) | Returns: a |
Gets the mount for the volume.
getName
data VolumeGetNameMethodInfo Source #
Instances
| (signature ~ m Text, MonadIO m, IsVolume a) => OverloadedMethod VolumeGetNameMethodInfo a signature Source # | |
Defined in GI.Gio.Interfaces.Volume Methods overloadedMethod :: a -> signature # | |
| OverloadedMethodInfo VolumeGetNameMethodInfo (a :: Type) Source # | |
Defined in GI.Gio.Interfaces.Volume Methods | |
Arguments
| :: (HasCallStack, MonadIO m, IsVolume a) | |
| => a |
|
| -> m Text | Returns: the name for the given |
Gets the name of volume.
getSortKey
data VolumeGetSortKeyMethodInfo Source #
Instances
| (signature ~ m (Maybe Text), MonadIO m, IsVolume a) => OverloadedMethod VolumeGetSortKeyMethodInfo a signature Source # | |
Defined in GI.Gio.Interfaces.Volume Methods overloadedMethod :: a -> signature # | |
| OverloadedMethodInfo VolumeGetSortKeyMethodInfo (a :: Type) Source # | |
Defined in GI.Gio.Interfaces.Volume Methods | |
Arguments
| :: (HasCallStack, MonadIO m, IsVolume a) | |
| => a |
|
| -> m (Maybe Text) | Returns: Sorting key for |
Gets the sort key for volume, if any.
Since: 2.32
getSymbolicIcon
data VolumeGetSymbolicIconMethodInfo Source #
Instances
| (signature ~ m Icon, MonadIO m, IsVolume a) => OverloadedMethod VolumeGetSymbolicIconMethodInfo a signature Source # | |
Defined in GI.Gio.Interfaces.Volume Methods overloadedMethod :: a -> signature # | |
| OverloadedMethodInfo VolumeGetSymbolicIconMethodInfo (a :: Type) Source # | |
Defined in GI.Gio.Interfaces.Volume Methods | |
volumeGetSymbolicIcon Source #
Arguments
| :: (HasCallStack, MonadIO m, IsVolume a) | |
| => a |
|
| -> m Icon | Returns: a |
Gets the symbolic icon for volume.
Since: 2.34
getUuid
data VolumeGetUuidMethodInfo Source #
Instances
| (signature ~ m (Maybe Text), MonadIO m, IsVolume a) => OverloadedMethod VolumeGetUuidMethodInfo a signature Source # | |
Defined in GI.Gio.Interfaces.Volume Methods overloadedMethod :: a -> signature # | |
| OverloadedMethodInfo VolumeGetUuidMethodInfo (a :: Type) Source # | |
Defined in GI.Gio.Interfaces.Volume Methods | |
Arguments
| :: (HasCallStack, MonadIO m, IsVolume a) | |
| => a |
|
| -> m (Maybe Text) | Returns: the UUID for |
Gets the UUID for the volume. The reference is typically based on
the file system UUID for the volume in question and should be
considered an opaque string. Returns Nothing if there is no UUID
available.
mount
data VolumeMountMethodInfo Source #
Instances
| (signature ~ ([MountMountFlags] -> Maybe b -> Maybe c -> Maybe AsyncReadyCallback -> m ()), MonadIO m, IsVolume a, IsMountOperation b, IsCancellable c) => OverloadedMethod VolumeMountMethodInfo a signature Source # | |
Defined in GI.Gio.Interfaces.Volume Methods overloadedMethod :: a -> signature # | |
| OverloadedMethodInfo VolumeMountMethodInfo (a :: Type) Source # | |
Defined in GI.Gio.Interfaces.Volume Methods | |
Arguments
| :: (HasCallStack, MonadIO m, IsVolume a, IsMountOperation b, IsCancellable c) | |
| => a |
|
| -> [MountMountFlags] |
|
| -> Maybe b |
|
| -> Maybe c |
|
| -> Maybe AsyncReadyCallback |
|
| -> m () |
Mounts a volume. This is an asynchronous operation, and is
finished by calling volumeMountFinish with the volume
and AsyncResult returned in the callback.
mountFinish
data VolumeMountFinishMethodInfo Source #
Instances
| (signature ~ (b -> m ()), MonadIO m, IsVolume a, IsAsyncResult b) => OverloadedMethod VolumeMountFinishMethodInfo a signature Source # | |
Defined in GI.Gio.Interfaces.Volume Methods overloadedMethod :: a -> signature # | |
| OverloadedMethodInfo VolumeMountFinishMethodInfo (a :: Type) Source # | |
Defined in GI.Gio.Interfaces.Volume Methods | |
Arguments
| :: (HasCallStack, MonadIO m, IsVolume a, IsAsyncResult b) | |
| => a |
|
| -> b |
|
| -> m () | (Can throw |
Finishes mounting a volume. If any errors occurred during the operation,
error will be set to contain the errors and False will be returned.
If the mount operation succeeded, volumeGetMount on volume
is guaranteed to return the mount right after calling this
function; there's no need to listen for the 'mount-added' signal on
VolumeMonitor.
shouldAutomount
data VolumeShouldAutomountMethodInfo Source #
Instances
| (signature ~ m Bool, MonadIO m, IsVolume a) => OverloadedMethod VolumeShouldAutomountMethodInfo a signature Source # | |
Defined in GI.Gio.Interfaces.Volume Methods overloadedMethod :: a -> signature # | |
| OverloadedMethodInfo VolumeShouldAutomountMethodInfo (a :: Type) Source # | |
Defined in GI.Gio.Interfaces.Volume Methods | |
volumeShouldAutomount Source #
Arguments
| :: (HasCallStack, MonadIO m, IsVolume a) | |
| => a |
|
| -> m Bool | Returns: |
Returns whether the volume should be automatically mounted.
Signals
changed
type VolumeChangedCallback = IO () Source #
Emitted when the volume has been changed.
data VolumeChangedSignalInfo Source #
Instances
| SignalInfo VolumeChangedSignalInfo Source # | |||||
Defined in GI.Gio.Interfaces.Volume Associated Types
Methods connectSignal :: GObject o => o -> (o -> HaskellCallbackType VolumeChangedSignalInfo) -> SignalConnectMode -> Maybe Text -> IO SignalHandlerId # | |||||
| type HaskellCallbackType VolumeChangedSignalInfo Source # | |||||
afterVolumeChanged :: (IsVolume a, MonadIO m) => a -> ((?self :: a) => VolumeChangedCallback) -> m SignalHandlerId Source #
Connect a signal handler for the changed signal, to be run after the default handler. When overloading is enabled, this is equivalent to
after volume #changed callback
By default the object invoking the signal is not passed to the callback.
If you need to access it, you can use the implit ?self parameter.
Note that this requires activating the ImplicitParams GHC extension.
onVolumeChanged :: (IsVolume a, MonadIO m) => a -> ((?self :: a) => VolumeChangedCallback) -> m SignalHandlerId Source #
Connect a signal handler for the changed signal, to be run before the default handler. When overloading is enabled, this is equivalent to
on volume #changed callback
removed
type VolumeRemovedCallback = IO () Source #
This signal is emitted when the Volume have been removed. If
the recipient is holding references to the object they should
release them so the object can be finalized.
data VolumeRemovedSignalInfo Source #
Instances
| SignalInfo VolumeRemovedSignalInfo Source # | |||||
Defined in GI.Gio.Interfaces.Volume Associated Types
Methods connectSignal :: GObject o => o -> (o -> HaskellCallbackType VolumeRemovedSignalInfo) -> SignalConnectMode -> Maybe Text -> IO SignalHandlerId # | |||||
| type HaskellCallbackType VolumeRemovedSignalInfo Source # | |||||
afterVolumeRemoved :: (IsVolume a, MonadIO m) => a -> ((?self :: a) => VolumeRemovedCallback) -> m SignalHandlerId Source #
Connect a signal handler for the removed signal, to be run after the default handler. When overloading is enabled, this is equivalent to
after volume #removed callback
By default the object invoking the signal is not passed to the callback.
If you need to access it, you can use the implit ?self parameter.
Note that this requires activating the ImplicitParams GHC extension.
onVolumeRemoved :: (IsVolume a, MonadIO m) => a -> ((?self :: a) => VolumeRemovedCallback) -> m SignalHandlerId Source #
Connect a signal handler for the removed signal, to be run before the default handler. When overloading is enabled, this is equivalent to
on volume #removed callback