| Copyright | Will Thompson and Iñaki García Etxebarria |
|---|---|
| License | LGPL-2.1 |
| Maintainer | Iñaki García Etxebarria |
| Safe Haskell | None |
| Language | Haskell2010 |
GI.Gio.Objects.FilenameCompleter
Description
Completes partial file and directory names given a partial string by looking in the file system for clues. Can return a list of possible completion strings for widget implementations.
Synopsis
- newtype FilenameCompleter = FilenameCompleter (ManagedPtr FilenameCompleter)
- class (GObject o, IsDescendantOf FilenameCompleter o) => IsFilenameCompleter o
- toFilenameCompleter :: (MonadIO m, IsFilenameCompleter o) => o -> m FilenameCompleter
- type family ResolveFilenameCompleterMethod (t :: Symbol) o where ...
- data FilenameCompleterGetCompletionSuffixMethodInfo
- filenameCompleterGetCompletionSuffix :: (HasCallStack, MonadIO m, IsFilenameCompleter a) => a -> Text -> m (Maybe Text)
- data FilenameCompleterGetCompletionsMethodInfo
- filenameCompleterGetCompletions :: (HasCallStack, MonadIO m, IsFilenameCompleter a) => a -> Text -> m [Text]
- filenameCompleterNew :: (HasCallStack, MonadIO m) => m FilenameCompleter
- data FilenameCompleterSetDirsOnlyMethodInfo
- filenameCompleterSetDirsOnly :: (HasCallStack, MonadIO m, IsFilenameCompleter a) => a -> Bool -> m ()
- type FilenameCompleterGotCompletionDataCallback = IO ()
- data FilenameCompleterGotCompletionDataSignalInfo
- afterFilenameCompleterGotCompletionData :: (IsFilenameCompleter a, MonadIO m) => a -> ((?self :: a) => FilenameCompleterGotCompletionDataCallback) -> m SignalHandlerId
- onFilenameCompleterGotCompletionData :: (IsFilenameCompleter a, MonadIO m) => a -> ((?self :: a) => FilenameCompleterGotCompletionDataCallback) -> m SignalHandlerId
Exported types
newtype FilenameCompleter Source #
Memory-managed wrapper type.
Constructors
| FilenameCompleter (ManagedPtr FilenameCompleter) |
Instances
class (GObject o, IsDescendantOf FilenameCompleter o) => IsFilenameCompleter o Source #
Type class for types which can be safely cast to FilenameCompleter, for instance with toFilenameCompleter.
Instances
| (GObject o, IsDescendantOf FilenameCompleter o) => IsFilenameCompleter o Source # | |
Defined in GI.Gio.Objects.FilenameCompleter | |
toFilenameCompleter :: (MonadIO m, IsFilenameCompleter o) => o -> m FilenameCompleter Source #
Cast to FilenameCompleter, for types for which this is known to be safe. For general casts, use castTo.
Methods
Click to display all available methods, including inherited ones
Methods
bindProperty, bindPropertyFull, forceFloating, freezeNotify, getv, isFloating, notify, notifyByPspec, ref, refSink, runDispose, stealData, stealQdata, thawNotify, unref, watchClosure.
Getters
getCompletionSuffix, getCompletions, getData, getProperty, getQdata.
Setters
type family ResolveFilenameCompleterMethod (t :: Symbol) o where ... Source #
Equations
getCompletionSuffix
data FilenameCompleterGetCompletionSuffixMethodInfo Source #
Instances
| (signature ~ (Text -> m (Maybe Text)), MonadIO m, IsFilenameCompleter a) => OverloadedMethod FilenameCompleterGetCompletionSuffixMethodInfo a signature Source # | |
Defined in GI.Gio.Objects.FilenameCompleter Methods overloadedMethod :: a -> signature # | |
| OverloadedMethodInfo FilenameCompleterGetCompletionSuffixMethodInfo (a :: Type) Source # | |
Defined in GI.Gio.Objects.FilenameCompleter Methods | |
filenameCompleterGetCompletionSuffix Source #
Arguments
| :: (HasCallStack, MonadIO m, IsFilenameCompleter a) | |
| => a |
|
| -> Text |
|
| -> m (Maybe Text) | Returns: a completed string, or |
Obtains a completion for initialText from completer.
getCompletions
data FilenameCompleterGetCompletionsMethodInfo Source #
Instances
| (signature ~ (Text -> m [Text]), MonadIO m, IsFilenameCompleter a) => OverloadedMethod FilenameCompleterGetCompletionsMethodInfo a signature Source # | |
Defined in GI.Gio.Objects.FilenameCompleter Methods overloadedMethod :: a -> signature # | |
| OverloadedMethodInfo FilenameCompleterGetCompletionsMethodInfo (a :: Type) Source # | |
Defined in GI.Gio.Objects.FilenameCompleter Methods | |
filenameCompleterGetCompletions Source #
Arguments
| :: (HasCallStack, MonadIO m, IsFilenameCompleter a) | |
| => a |
|
| -> Text |
|
| -> m [Text] | Returns: array of strings with possible completions for |
Gets an array of completion strings for a given initial text.
new
Arguments
| :: (HasCallStack, MonadIO m) | |
| => m FilenameCompleter | Returns: a |
Creates a new filename completer.
setDirsOnly
data FilenameCompleterSetDirsOnlyMethodInfo Source #
Instances
| (signature ~ (Bool -> m ()), MonadIO m, IsFilenameCompleter a) => OverloadedMethod FilenameCompleterSetDirsOnlyMethodInfo a signature Source # | |
Defined in GI.Gio.Objects.FilenameCompleter Methods overloadedMethod :: a -> signature # | |
| OverloadedMethodInfo FilenameCompleterSetDirsOnlyMethodInfo (a :: Type) Source # | |
Defined in GI.Gio.Objects.FilenameCompleter Methods | |
filenameCompleterSetDirsOnly Source #
Arguments
| :: (HasCallStack, MonadIO m, IsFilenameCompleter a) | |
| => a |
|
| -> Bool |
|
| -> m () |
If dirsOnly is True, completer will only
complete directory names, and not file names.
Signals
gotCompletionData
type FilenameCompleterGotCompletionDataCallback = IO () Source #
Emitted when the file name completion information comes available.
data FilenameCompleterGotCompletionDataSignalInfo Source #
Instances
| SignalInfo FilenameCompleterGotCompletionDataSignalInfo Source # | |||||
Defined in GI.Gio.Objects.FilenameCompleter Associated Types
Methods connectSignal :: GObject o => o -> (o -> HaskellCallbackType FilenameCompleterGotCompletionDataSignalInfo) -> SignalConnectMode -> Maybe Text -> IO SignalHandlerId # | |||||
| type HaskellCallbackType FilenameCompleterGotCompletionDataSignalInfo Source # | |||||
afterFilenameCompleterGotCompletionData :: (IsFilenameCompleter a, MonadIO m) => a -> ((?self :: a) => FilenameCompleterGotCompletionDataCallback) -> m SignalHandlerId Source #
Connect a signal handler for the gotCompletionData signal, to be run after the default handler. When overloading is enabled, this is equivalent to
after filenameCompleter #gotCompletionData callback
By default the object invoking the signal is not passed to the callback.
If you need to access it, you can use the implit ?self parameter.
Note that this requires activating the ImplicitParams GHC extension.
onFilenameCompleterGotCompletionData :: (IsFilenameCompleter a, MonadIO m) => a -> ((?self :: a) => FilenameCompleterGotCompletionDataCallback) -> m SignalHandlerId Source #
Connect a signal handler for the gotCompletionData signal, to be run before the default handler. When overloading is enabled, this is equivalent to
on filenameCompleter #gotCompletionData callback