| Copyright | Will Thompson and Iñaki García Etxebarria |
|---|---|
| License | LGPL-2.1 |
| Maintainer | Iñaki García Etxebarria |
| Safe Haskell | None |
| Language | Haskell2010 |
GI.Gio.Objects.PropertyAction
Description
A GPropertyAction is a way to get a Action with a state value
reflecting and controlling the value of a Object property.
The state of the action will correspond to the value of the property.
Changing it will change the property (assuming the requested value
matches the requirements as specified in the [typegObject.ParamSpec]).
Only the most common types are presently supported. Booleans are mapped to booleans, strings to strings, signed/unsigned integers to int32/uint32 and floats and doubles to doubles.
If the property is an enum then the state will be string-typed and
conversion will automatically be performed between the enum value and
‘nick’ string as per the [typegObject.EnumValue] table.
Flags types are not currently supported.
Properties of object types, boxed types and pointer types are not supported and probably never will be.
Properties of [typegLib.Variant] types are not currently supported.
If the property is boolean-valued then the action will have a NULL
parameter type, and activating the action (with no parameter) will
toggle the value of the property.
In all other cases, the parameter type will correspond to the type of the property.
The general idea here is to reduce the number of locations where a
particular piece of state is kept (and therefore has to be synchronised
between). GPropertyAction does not have a separate state that is kept
in sync with the property value — its state is the property value.
For example, it might be useful to create a Action corresponding
to the visible-child-name property of a `GtkStack`
so that the current page can be switched from a menu. The active radio
indication in the menu is then directly determined from the active page of
the GtkStack.
An anti-example would be binding the active-id property on a
`GtkComboBox`. This is
because the state of the combo box itself is probably uninteresting and is
actually being used to control something else.
Another anti-example would be to bind to the visible-child-name
property of a `GtkStack` if
this value is actually stored in Settings. In that case, the
real source of the value is* Settings. If you want
a Action to control a setting stored in Settings,
see settingsCreateAction instead, and possibly combine its
use with settingsBind.
Since: 2.38
Synopsis
- newtype PropertyAction = PropertyAction (ManagedPtr PropertyAction)
- class (GObject o, IsDescendantOf PropertyAction o) => IsPropertyAction o
- toPropertyAction :: (MonadIO m, IsPropertyAction o) => o -> m PropertyAction
- type family ResolvePropertyActionMethod (t :: Symbol) o where ...
- propertyActionNew :: (HasCallStack, MonadIO m, IsObject a) => Text -> a -> Text -> m PropertyAction
- data PropertyActionEnabledPropertyInfo
- getPropertyActionEnabled :: (MonadIO m, IsPropertyAction o) => o -> m Bool
- propertyActionEnabled :: AttrLabelProxy "enabled"
- data PropertyActionInvertBooleanPropertyInfo
- constructPropertyActionInvertBoolean :: (IsPropertyAction o, MonadIO m) => Bool -> m (GValueConstruct o)
- getPropertyActionInvertBoolean :: (MonadIO m, IsPropertyAction o) => o -> m Bool
- propertyActionInvertBoolean :: AttrLabelProxy "invertBoolean"
- data PropertyActionNamePropertyInfo
- constructPropertyActionName :: (IsPropertyAction o, MonadIO m) => Text -> m (GValueConstruct o)
- getPropertyActionName :: (MonadIO m, IsPropertyAction o) => o -> m (Maybe Text)
- propertyActionName :: AttrLabelProxy "name"
- data PropertyActionObjectPropertyInfo
- constructPropertyActionObject :: (IsPropertyAction o, MonadIO m, IsObject a) => a -> m (GValueConstruct o)
- propertyActionObject :: AttrLabelProxy "object"
- data PropertyActionParameterTypePropertyInfo
- getPropertyActionParameterType :: (MonadIO m, IsPropertyAction o) => o -> m (Maybe VariantType)
- propertyActionParameterType :: AttrLabelProxy "parameterType"
- data PropertyActionPropertyNamePropertyInfo
- constructPropertyActionPropertyName :: (IsPropertyAction o, MonadIO m) => Text -> m (GValueConstruct o)
- propertyActionPropertyName :: AttrLabelProxy "propertyName"
- data PropertyActionStatePropertyInfo
- getPropertyActionState :: (MonadIO m, IsPropertyAction o) => o -> m (Maybe GVariant)
- propertyActionState :: AttrLabelProxy "state"
- data PropertyActionStateTypePropertyInfo
- getPropertyActionStateType :: (MonadIO m, IsPropertyAction o) => o -> m (Maybe VariantType)
- propertyActionStateType :: AttrLabelProxy "stateType"
Exported types
newtype PropertyAction Source #
Memory-managed wrapper type.
Constructors
| PropertyAction (ManagedPtr PropertyAction) |
Instances
class (GObject o, IsDescendantOf PropertyAction o) => IsPropertyAction o Source #
Type class for types which can be safely cast to PropertyAction, for instance with toPropertyAction.
Instances
| (GObject o, IsDescendantOf PropertyAction o) => IsPropertyAction o Source # | |
Defined in GI.Gio.Objects.PropertyAction | |
toPropertyAction :: (MonadIO m, IsPropertyAction o) => o -> m PropertyAction Source #
Cast to PropertyAction, for types for which this is known to be safe. For general casts, use castTo.
Methods
Click to display all available methods, including inherited ones
Methods
activate, bindProperty, bindPropertyFull, changeState, forceFloating, freezeNotify, getv, isFloating, notify, notifyByPspec, ref, refSink, runDispose, stealData, stealQdata, thawNotify, unref, watchClosure.
Getters
getData, getEnabled, getName, getParameterType, getProperty, getQdata, getState, getStateHint, getStateType.
Setters
type family ResolvePropertyActionMethod (t :: Symbol) o where ... Source #
Equations
new
Arguments
| :: (HasCallStack, MonadIO m, IsObject a) | |
| => Text |
|
| -> a |
|
| -> Text |
|
| -> m PropertyAction | Returns: a new |
Creates a Action corresponding to the value of property
propertyName on object.
The property must be existent and readable and writable (and not construct-only).
This function takes a reference on object and doesn't release it
until the action is destroyed.
Since: 2.38
Properties
enabled
If action is currently enabled.
If the action is disabled then calls to actionActivate and
actionChangeState have no effect.
Since: 2.38
data PropertyActionEnabledPropertyInfo Source #
Instances
getPropertyActionEnabled :: (MonadIO m, IsPropertyAction o) => o -> m Bool Source #
Get the value of the “enabled” property.
When overloading is enabled, this is equivalent to
get propertyAction #enabled
propertyActionEnabled :: AttrLabelProxy "enabled" Source #
invertBoolean
If True, the state of the action will be the negation of the
property value, provided the property is boolean.
Since: 2.46
data PropertyActionInvertBooleanPropertyInfo Source #
Instances
| AttrInfo PropertyActionInvertBooleanPropertyInfo Source # | |||||||||||||||||||||||||||||||||
Defined in GI.Gio.Objects.PropertyAction Associated Types
Methods attrGet :: AttrBaseTypeConstraint PropertyActionInvertBooleanPropertyInfo o => o -> IO (AttrGetType PropertyActionInvertBooleanPropertyInfo) # attrSet :: (AttrBaseTypeConstraint PropertyActionInvertBooleanPropertyInfo o, AttrSetTypeConstraint PropertyActionInvertBooleanPropertyInfo b) => o -> b -> IO () # attrClear :: AttrBaseTypeConstraint PropertyActionInvertBooleanPropertyInfo o => o -> IO () # attrConstruct :: (AttrBaseTypeConstraint PropertyActionInvertBooleanPropertyInfo o, AttrSetTypeConstraint PropertyActionInvertBooleanPropertyInfo b) => b -> IO (GValueConstruct o) # attrTransfer :: (AttrBaseTypeConstraint PropertyActionInvertBooleanPropertyInfo o, AttrTransferTypeConstraint PropertyActionInvertBooleanPropertyInfo b) => Proxy o -> b -> IO (AttrTransferType PropertyActionInvertBooleanPropertyInfo) # | |||||||||||||||||||||||||||||||||
| type AttrAllowedOps PropertyActionInvertBooleanPropertyInfo Source # | |||||||||||||||||||||||||||||||||
Defined in GI.Gio.Objects.PropertyAction | |||||||||||||||||||||||||||||||||
| type AttrBaseTypeConstraint PropertyActionInvertBooleanPropertyInfo Source # | |||||||||||||||||||||||||||||||||
| type AttrGetType PropertyActionInvertBooleanPropertyInfo Source # | |||||||||||||||||||||||||||||||||
Defined in GI.Gio.Objects.PropertyAction | |||||||||||||||||||||||||||||||||
| type AttrLabel PropertyActionInvertBooleanPropertyInfo Source # | |||||||||||||||||||||||||||||||||
Defined in GI.Gio.Objects.PropertyAction | |||||||||||||||||||||||||||||||||
| type AttrOrigin PropertyActionInvertBooleanPropertyInfo Source # | |||||||||||||||||||||||||||||||||
| type AttrSetTypeConstraint PropertyActionInvertBooleanPropertyInfo Source # | |||||||||||||||||||||||||||||||||
| type AttrTransferType PropertyActionInvertBooleanPropertyInfo Source # | |||||||||||||||||||||||||||||||||
| type AttrTransferTypeConstraint PropertyActionInvertBooleanPropertyInfo Source # | |||||||||||||||||||||||||||||||||
constructPropertyActionInvertBoolean :: (IsPropertyAction o, MonadIO m) => Bool -> m (GValueConstruct o) Source #
Construct a GValueConstruct with valid value for the “invert-boolean” property. This is rarely needed directly, but it is used by new.
getPropertyActionInvertBoolean :: (MonadIO m, IsPropertyAction o) => o -> m Bool Source #
Get the value of the “invert-boolean” property.
When overloading is enabled, this is equivalent to
get propertyAction #invertBoolean
propertyActionInvertBoolean :: AttrLabelProxy "invertBoolean" Source #
name
The name of the action. This is mostly meaningful for identifying
the action once it has been added to a ActionMap.
Since: 2.38
data PropertyActionNamePropertyInfo Source #
Instances
| AttrInfo PropertyActionNamePropertyInfo Source # | |||||||||||||||||||||||||||||||||
Defined in GI.Gio.Objects.PropertyAction Associated Types
Methods attrGet :: AttrBaseTypeConstraint PropertyActionNamePropertyInfo o => o -> IO (AttrGetType PropertyActionNamePropertyInfo) # attrSet :: (AttrBaseTypeConstraint PropertyActionNamePropertyInfo o, AttrSetTypeConstraint PropertyActionNamePropertyInfo b) => o -> b -> IO () # attrClear :: AttrBaseTypeConstraint PropertyActionNamePropertyInfo o => o -> IO () # attrConstruct :: (AttrBaseTypeConstraint PropertyActionNamePropertyInfo o, AttrSetTypeConstraint PropertyActionNamePropertyInfo b) => b -> IO (GValueConstruct o) # attrTransfer :: (AttrBaseTypeConstraint PropertyActionNamePropertyInfo o, AttrTransferTypeConstraint PropertyActionNamePropertyInfo b) => Proxy o -> b -> IO (AttrTransferType PropertyActionNamePropertyInfo) # | |||||||||||||||||||||||||||||||||
| type AttrAllowedOps PropertyActionNamePropertyInfo Source # | |||||||||||||||||||||||||||||||||
Defined in GI.Gio.Objects.PropertyAction | |||||||||||||||||||||||||||||||||
| type AttrBaseTypeConstraint PropertyActionNamePropertyInfo Source # | |||||||||||||||||||||||||||||||||
| type AttrGetType PropertyActionNamePropertyInfo Source # | |||||||||||||||||||||||||||||||||
Defined in GI.Gio.Objects.PropertyAction | |||||||||||||||||||||||||||||||||
| type AttrLabel PropertyActionNamePropertyInfo Source # | |||||||||||||||||||||||||||||||||
Defined in GI.Gio.Objects.PropertyAction | |||||||||||||||||||||||||||||||||
| type AttrOrigin PropertyActionNamePropertyInfo Source # | |||||||||||||||||||||||||||||||||
Defined in GI.Gio.Objects.PropertyAction | |||||||||||||||||||||||||||||||||
| type AttrSetTypeConstraint PropertyActionNamePropertyInfo Source # | |||||||||||||||||||||||||||||||||
Defined in GI.Gio.Objects.PropertyAction | |||||||||||||||||||||||||||||||||
| type AttrTransferType PropertyActionNamePropertyInfo Source # | |||||||||||||||||||||||||||||||||
Defined in GI.Gio.Objects.PropertyAction | |||||||||||||||||||||||||||||||||
| type AttrTransferTypeConstraint PropertyActionNamePropertyInfo Source # | |||||||||||||||||||||||||||||||||
constructPropertyActionName :: (IsPropertyAction o, MonadIO m) => Text -> m (GValueConstruct o) Source #
Construct a GValueConstruct with valid value for the “name” property. This is rarely needed directly, but it is used by new.
getPropertyActionName :: (MonadIO m, IsPropertyAction o) => o -> m (Maybe Text) Source #
Get the value of the “name” property.
When overloading is enabled, this is equivalent to
get propertyAction #name
propertyActionName :: AttrLabelProxy "name" Source #
object
The object to wrap a property on.
The object must be a non-Nothing Object with properties.
Since: 2.38
data PropertyActionObjectPropertyInfo Source #
Instances
| AttrInfo PropertyActionObjectPropertyInfo Source # | |||||||||||||||||||||||||||||||||
Defined in GI.Gio.Objects.PropertyAction Associated Types
Methods attrGet :: AttrBaseTypeConstraint PropertyActionObjectPropertyInfo o => o -> IO (AttrGetType PropertyActionObjectPropertyInfo) # attrSet :: (AttrBaseTypeConstraint PropertyActionObjectPropertyInfo o, AttrSetTypeConstraint PropertyActionObjectPropertyInfo b) => o -> b -> IO () # attrClear :: AttrBaseTypeConstraint PropertyActionObjectPropertyInfo o => o -> IO () # attrConstruct :: (AttrBaseTypeConstraint PropertyActionObjectPropertyInfo o, AttrSetTypeConstraint PropertyActionObjectPropertyInfo b) => b -> IO (GValueConstruct o) # attrTransfer :: (AttrBaseTypeConstraint PropertyActionObjectPropertyInfo o, AttrTransferTypeConstraint PropertyActionObjectPropertyInfo b) => Proxy o -> b -> IO (AttrTransferType PropertyActionObjectPropertyInfo) # | |||||||||||||||||||||||||||||||||
| type AttrAllowedOps PropertyActionObjectPropertyInfo Source # | |||||||||||||||||||||||||||||||||
Defined in GI.Gio.Objects.PropertyAction | |||||||||||||||||||||||||||||||||
| type AttrBaseTypeConstraint PropertyActionObjectPropertyInfo Source # | |||||||||||||||||||||||||||||||||
| type AttrGetType PropertyActionObjectPropertyInfo Source # | |||||||||||||||||||||||||||||||||
Defined in GI.Gio.Objects.PropertyAction | |||||||||||||||||||||||||||||||||
| type AttrLabel PropertyActionObjectPropertyInfo Source # | |||||||||||||||||||||||||||||||||
Defined in GI.Gio.Objects.PropertyAction | |||||||||||||||||||||||||||||||||
| type AttrOrigin PropertyActionObjectPropertyInfo Source # | |||||||||||||||||||||||||||||||||
| type AttrSetTypeConstraint PropertyActionObjectPropertyInfo Source # | |||||||||||||||||||||||||||||||||
| type AttrTransferType PropertyActionObjectPropertyInfo Source # | |||||||||||||||||||||||||||||||||
Defined in GI.Gio.Objects.PropertyAction | |||||||||||||||||||||||||||||||||
| type AttrTransferTypeConstraint PropertyActionObjectPropertyInfo Source # | |||||||||||||||||||||||||||||||||
constructPropertyActionObject :: (IsPropertyAction o, MonadIO m, IsObject a) => a -> m (GValueConstruct o) Source #
Construct a GValueConstruct with valid value for the “object” property. This is rarely needed directly, but it is used by new.
propertyActionObject :: AttrLabelProxy "object" Source #
parameterType
The type of the parameter that must be given when activating the action.
Since: 2.38
data PropertyActionParameterTypePropertyInfo Source #
Instances
| AttrInfo PropertyActionParameterTypePropertyInfo Source # | |||||||||||||||||||||||||||||||||
Defined in GI.Gio.Objects.PropertyAction Associated Types
Methods attrGet :: AttrBaseTypeConstraint PropertyActionParameterTypePropertyInfo o => o -> IO (AttrGetType PropertyActionParameterTypePropertyInfo) # attrSet :: (AttrBaseTypeConstraint PropertyActionParameterTypePropertyInfo o, AttrSetTypeConstraint PropertyActionParameterTypePropertyInfo b) => o -> b -> IO () # attrClear :: AttrBaseTypeConstraint PropertyActionParameterTypePropertyInfo o => o -> IO () # attrConstruct :: (AttrBaseTypeConstraint PropertyActionParameterTypePropertyInfo o, AttrSetTypeConstraint PropertyActionParameterTypePropertyInfo b) => b -> IO (GValueConstruct o) # attrTransfer :: (AttrBaseTypeConstraint PropertyActionParameterTypePropertyInfo o, AttrTransferTypeConstraint PropertyActionParameterTypePropertyInfo b) => Proxy o -> b -> IO (AttrTransferType PropertyActionParameterTypePropertyInfo) # | |||||||||||||||||||||||||||||||||
| type AttrAllowedOps PropertyActionParameterTypePropertyInfo Source # | |||||||||||||||||||||||||||||||||
Defined in GI.Gio.Objects.PropertyAction | |||||||||||||||||||||||||||||||||
| type AttrBaseTypeConstraint PropertyActionParameterTypePropertyInfo Source # | |||||||||||||||||||||||||||||||||
| type AttrGetType PropertyActionParameterTypePropertyInfo Source # | |||||||||||||||||||||||||||||||||
| type AttrLabel PropertyActionParameterTypePropertyInfo Source # | |||||||||||||||||||||||||||||||||
Defined in GI.Gio.Objects.PropertyAction | |||||||||||||||||||||||||||||||||
| type AttrOrigin PropertyActionParameterTypePropertyInfo Source # | |||||||||||||||||||||||||||||||||
| type AttrSetTypeConstraint PropertyActionParameterTypePropertyInfo Source # | |||||||||||||||||||||||||||||||||
Defined in GI.Gio.Objects.PropertyAction | |||||||||||||||||||||||||||||||||
| type AttrTransferType PropertyActionParameterTypePropertyInfo Source # | |||||||||||||||||||||||||||||||||
Defined in GI.Gio.Objects.PropertyAction | |||||||||||||||||||||||||||||||||
| type AttrTransferTypeConstraint PropertyActionParameterTypePropertyInfo Source # | |||||||||||||||||||||||||||||||||
Defined in GI.Gio.Objects.PropertyAction | |||||||||||||||||||||||||||||||||
getPropertyActionParameterType :: (MonadIO m, IsPropertyAction o) => o -> m (Maybe VariantType) Source #
Get the value of the “parameter-type” property.
When overloading is enabled, this is equivalent to
get propertyAction #parameterType
propertyActionParameterType :: AttrLabelProxy "parameterType" Source #
propertyName
The name of the property to wrap on the object.
The property must exist on the passed-in object and it must be readable and writable (and not construct-only).
Since: 2.38
data PropertyActionPropertyNamePropertyInfo Source #
Instances
| AttrInfo PropertyActionPropertyNamePropertyInfo Source # | |||||||||||||||||||||||||||||||||
Defined in GI.Gio.Objects.PropertyAction Associated Types
Methods attrGet :: AttrBaseTypeConstraint PropertyActionPropertyNamePropertyInfo o => o -> IO (AttrGetType PropertyActionPropertyNamePropertyInfo) # attrSet :: (AttrBaseTypeConstraint PropertyActionPropertyNamePropertyInfo o, AttrSetTypeConstraint PropertyActionPropertyNamePropertyInfo b) => o -> b -> IO () # attrClear :: AttrBaseTypeConstraint PropertyActionPropertyNamePropertyInfo o => o -> IO () # attrConstruct :: (AttrBaseTypeConstraint PropertyActionPropertyNamePropertyInfo o, AttrSetTypeConstraint PropertyActionPropertyNamePropertyInfo b) => b -> IO (GValueConstruct o) # attrTransfer :: (AttrBaseTypeConstraint PropertyActionPropertyNamePropertyInfo o, AttrTransferTypeConstraint PropertyActionPropertyNamePropertyInfo b) => Proxy o -> b -> IO (AttrTransferType PropertyActionPropertyNamePropertyInfo) # | |||||||||||||||||||||||||||||||||
| type AttrAllowedOps PropertyActionPropertyNamePropertyInfo Source # | |||||||||||||||||||||||||||||||||
Defined in GI.Gio.Objects.PropertyAction | |||||||||||||||||||||||||||||||||
| type AttrBaseTypeConstraint PropertyActionPropertyNamePropertyInfo Source # | |||||||||||||||||||||||||||||||||
| type AttrGetType PropertyActionPropertyNamePropertyInfo Source # | |||||||||||||||||||||||||||||||||
Defined in GI.Gio.Objects.PropertyAction | |||||||||||||||||||||||||||||||||
| type AttrLabel PropertyActionPropertyNamePropertyInfo Source # | |||||||||||||||||||||||||||||||||
Defined in GI.Gio.Objects.PropertyAction | |||||||||||||||||||||||||||||||||
| type AttrOrigin PropertyActionPropertyNamePropertyInfo Source # | |||||||||||||||||||||||||||||||||
| type AttrSetTypeConstraint PropertyActionPropertyNamePropertyInfo Source # | |||||||||||||||||||||||||||||||||
| type AttrTransferType PropertyActionPropertyNamePropertyInfo Source # | |||||||||||||||||||||||||||||||||
| type AttrTransferTypeConstraint PropertyActionPropertyNamePropertyInfo Source # | |||||||||||||||||||||||||||||||||
constructPropertyActionPropertyName :: (IsPropertyAction o, MonadIO m) => Text -> m (GValueConstruct o) Source #
Construct a GValueConstruct with valid value for the “property-name” property. This is rarely needed directly, but it is used by new.
propertyActionPropertyName :: AttrLabelProxy "propertyName" Source #
state
The state of the action, or Nothing if the action is stateless.
Since: 2.38
data PropertyActionStatePropertyInfo Source #
Instances
| AttrInfo PropertyActionStatePropertyInfo Source # | |||||||||||||||||||||||||||||||||
Defined in GI.Gio.Objects.PropertyAction Associated Types
Methods attrGet :: AttrBaseTypeConstraint PropertyActionStatePropertyInfo o => o -> IO (AttrGetType PropertyActionStatePropertyInfo) # attrSet :: (AttrBaseTypeConstraint PropertyActionStatePropertyInfo o, AttrSetTypeConstraint PropertyActionStatePropertyInfo b) => o -> b -> IO () # attrClear :: AttrBaseTypeConstraint PropertyActionStatePropertyInfo o => o -> IO () # attrConstruct :: (AttrBaseTypeConstraint PropertyActionStatePropertyInfo o, AttrSetTypeConstraint PropertyActionStatePropertyInfo b) => b -> IO (GValueConstruct o) # attrTransfer :: (AttrBaseTypeConstraint PropertyActionStatePropertyInfo o, AttrTransferTypeConstraint PropertyActionStatePropertyInfo b) => Proxy o -> b -> IO (AttrTransferType PropertyActionStatePropertyInfo) # | |||||||||||||||||||||||||||||||||
| type AttrAllowedOps PropertyActionStatePropertyInfo Source # | |||||||||||||||||||||||||||||||||
Defined in GI.Gio.Objects.PropertyAction | |||||||||||||||||||||||||||||||||
| type AttrBaseTypeConstraint PropertyActionStatePropertyInfo Source # | |||||||||||||||||||||||||||||||||
| type AttrGetType PropertyActionStatePropertyInfo Source # | |||||||||||||||||||||||||||||||||
Defined in GI.Gio.Objects.PropertyAction | |||||||||||||||||||||||||||||||||
| type AttrLabel PropertyActionStatePropertyInfo Source # | |||||||||||||||||||||||||||||||||
Defined in GI.Gio.Objects.PropertyAction | |||||||||||||||||||||||||||||||||
| type AttrOrigin PropertyActionStatePropertyInfo Source # | |||||||||||||||||||||||||||||||||
Defined in GI.Gio.Objects.PropertyAction | |||||||||||||||||||||||||||||||||
| type AttrSetTypeConstraint PropertyActionStatePropertyInfo Source # | |||||||||||||||||||||||||||||||||
Defined in GI.Gio.Objects.PropertyAction | |||||||||||||||||||||||||||||||||
| type AttrTransferType PropertyActionStatePropertyInfo Source # | |||||||||||||||||||||||||||||||||
Defined in GI.Gio.Objects.PropertyAction | |||||||||||||||||||||||||||||||||
| type AttrTransferTypeConstraint PropertyActionStatePropertyInfo Source # | |||||||||||||||||||||||||||||||||
Defined in GI.Gio.Objects.PropertyAction | |||||||||||||||||||||||||||||||||
getPropertyActionState :: (MonadIO m, IsPropertyAction o) => o -> m (Maybe GVariant) Source #
Get the value of the “state” property.
When overloading is enabled, this is equivalent to
get propertyAction #state
propertyActionState :: AttrLabelProxy "state" Source #
stateType
The VariantType of the state that the action has, or Nothing if the
action is stateless.
Since: 2.38
data PropertyActionStateTypePropertyInfo Source #
Instances
| AttrInfo PropertyActionStateTypePropertyInfo Source # | |||||||||||||||||||||||||||||||||
Defined in GI.Gio.Objects.PropertyAction Associated Types
Methods attrGet :: AttrBaseTypeConstraint PropertyActionStateTypePropertyInfo o => o -> IO (AttrGetType PropertyActionStateTypePropertyInfo) # attrSet :: (AttrBaseTypeConstraint PropertyActionStateTypePropertyInfo o, AttrSetTypeConstraint PropertyActionStateTypePropertyInfo b) => o -> b -> IO () # attrClear :: AttrBaseTypeConstraint PropertyActionStateTypePropertyInfo o => o -> IO () # attrConstruct :: (AttrBaseTypeConstraint PropertyActionStateTypePropertyInfo o, AttrSetTypeConstraint PropertyActionStateTypePropertyInfo b) => b -> IO (GValueConstruct o) # attrTransfer :: (AttrBaseTypeConstraint PropertyActionStateTypePropertyInfo o, AttrTransferTypeConstraint PropertyActionStateTypePropertyInfo b) => Proxy o -> b -> IO (AttrTransferType PropertyActionStateTypePropertyInfo) # | |||||||||||||||||||||||||||||||||
| type AttrAllowedOps PropertyActionStateTypePropertyInfo Source # | |||||||||||||||||||||||||||||||||
Defined in GI.Gio.Objects.PropertyAction | |||||||||||||||||||||||||||||||||
| type AttrBaseTypeConstraint PropertyActionStateTypePropertyInfo Source # | |||||||||||||||||||||||||||||||||
| type AttrGetType PropertyActionStateTypePropertyInfo Source # | |||||||||||||||||||||||||||||||||
| type AttrLabel PropertyActionStateTypePropertyInfo Source # | |||||||||||||||||||||||||||||||||
Defined in GI.Gio.Objects.PropertyAction | |||||||||||||||||||||||||||||||||
| type AttrOrigin PropertyActionStateTypePropertyInfo Source # | |||||||||||||||||||||||||||||||||
| type AttrSetTypeConstraint PropertyActionStateTypePropertyInfo Source # | |||||||||||||||||||||||||||||||||
Defined in GI.Gio.Objects.PropertyAction | |||||||||||||||||||||||||||||||||
| type AttrTransferType PropertyActionStateTypePropertyInfo Source # | |||||||||||||||||||||||||||||||||
Defined in GI.Gio.Objects.PropertyAction | |||||||||||||||||||||||||||||||||
| type AttrTransferTypeConstraint PropertyActionStateTypePropertyInfo Source # | |||||||||||||||||||||||||||||||||
Defined in GI.Gio.Objects.PropertyAction | |||||||||||||||||||||||||||||||||
getPropertyActionStateType :: (MonadIO m, IsPropertyAction o) => o -> m (Maybe VariantType) Source #
Get the value of the “state-type” property.
When overloading is enabled, this is equivalent to
get propertyAction #stateType
propertyActionStateType :: AttrLabelProxy "stateType" Source #