| Copyright | Will Thompson and Iñaki García Etxebarria |
|---|---|
| License | LGPL-2.1 |
| Maintainer | Iñaki García Etxebarria |
| Safe Haskell | None |
| Language | Haskell2010 |
GI.Gio.Objects.ProxyAddressEnumerator
Description
GProxyAddressEnumerator is a wrapper around
SocketAddressEnumerator which takes the SocketAddress
instances returned by the SocketAddressEnumerator
and wraps them in ProxyAddress instances, using the given
ProxyAddressEnumerator:proxyResolver.
This enumerator will be returned (for example, by
socketConnectableEnumerate) as appropriate when a proxy is
configured; there should be no need to manually wrap a
SocketAddressEnumerator instance with one.
Synopsis
- newtype ProxyAddressEnumerator = ProxyAddressEnumerator (ManagedPtr ProxyAddressEnumerator)
- class (GObject o, IsDescendantOf ProxyAddressEnumerator o) => IsProxyAddressEnumerator o
- toProxyAddressEnumerator :: (MonadIO m, IsProxyAddressEnumerator o) => o -> m ProxyAddressEnumerator
- type family ResolveProxyAddressEnumeratorMethod (t :: Symbol) o where ...
- data ProxyAddressEnumeratorConnectablePropertyInfo
- constructProxyAddressEnumeratorConnectable :: (IsProxyAddressEnumerator o, MonadIO m, IsSocketConnectable a) => a -> m (GValueConstruct o)
- getProxyAddressEnumeratorConnectable :: (MonadIO m, IsProxyAddressEnumerator o) => o -> m (Maybe SocketConnectable)
- proxyAddressEnumeratorConnectable :: AttrLabelProxy "connectable"
- data ProxyAddressEnumeratorDefaultPortPropertyInfo
- constructProxyAddressEnumeratorDefaultPort :: (IsProxyAddressEnumerator o, MonadIO m) => Word32 -> m (GValueConstruct o)
- getProxyAddressEnumeratorDefaultPort :: (MonadIO m, IsProxyAddressEnumerator o) => o -> m Word32
- proxyAddressEnumeratorDefaultPort :: AttrLabelProxy "defaultPort"
- data ProxyAddressEnumeratorProxyResolverPropertyInfo
- clearProxyAddressEnumeratorProxyResolver :: (MonadIO m, IsProxyAddressEnumerator o) => o -> m ()
- constructProxyAddressEnumeratorProxyResolver :: (IsProxyAddressEnumerator o, MonadIO m, IsProxyResolver a) => a -> m (GValueConstruct o)
- getProxyAddressEnumeratorProxyResolver :: (MonadIO m, IsProxyAddressEnumerator o) => o -> m (Maybe ProxyResolver)
- proxyAddressEnumeratorProxyResolver :: AttrLabelProxy "proxyResolver"
- setProxyAddressEnumeratorProxyResolver :: (MonadIO m, IsProxyAddressEnumerator o, IsProxyResolver a) => o -> a -> m ()
- data ProxyAddressEnumeratorUriPropertyInfo
- constructProxyAddressEnumeratorUri :: (IsProxyAddressEnumerator o, MonadIO m) => Text -> m (GValueConstruct o)
- getProxyAddressEnumeratorUri :: (MonadIO m, IsProxyAddressEnumerator o) => o -> m (Maybe Text)
- proxyAddressEnumeratorUri :: AttrLabelProxy "uri"
Exported types
newtype ProxyAddressEnumerator Source #
Memory-managed wrapper type.
Constructors
| ProxyAddressEnumerator (ManagedPtr ProxyAddressEnumerator) |
Instances
class (GObject o, IsDescendantOf ProxyAddressEnumerator o) => IsProxyAddressEnumerator o Source #
Type class for types which can be safely cast to ProxyAddressEnumerator, for instance with toProxyAddressEnumerator.
Instances
| (GObject o, IsDescendantOf ProxyAddressEnumerator o) => IsProxyAddressEnumerator o Source # | |
Defined in GI.Gio.Objects.ProxyAddressEnumerator | |
toProxyAddressEnumerator :: (MonadIO m, IsProxyAddressEnumerator o) => o -> m ProxyAddressEnumerator Source #
Cast to ProxyAddressEnumerator, for types for which this is known to be safe. For general casts, use castTo.
Methods
Click to display all available methods, including inherited ones
Methods
bindProperty, bindPropertyFull, forceFloating, freezeNotify, getv, isFloating, next, nextAsync, nextFinish, notify, notifyByPspec, ref, refSink, runDispose, stealData, stealQdata, thawNotify, unref, watchClosure.
Getters
getData, getProperty, getQdata.
Setters
type family ResolveProxyAddressEnumeratorMethod (t :: Symbol) o where ... Source #
Equations
Properties
connectable
The connectable being enumerated.
data ProxyAddressEnumeratorConnectablePropertyInfo Source #
Instances
constructProxyAddressEnumeratorConnectable :: (IsProxyAddressEnumerator o, MonadIO m, IsSocketConnectable a) => a -> m (GValueConstruct o) Source #
Construct a GValueConstruct with valid value for the “connectable” property. This is rarely needed directly, but it is used by new.
getProxyAddressEnumeratorConnectable :: (MonadIO m, IsProxyAddressEnumerator o) => o -> m (Maybe SocketConnectable) Source #
Get the value of the “connectable” property.
When overloading is enabled, this is equivalent to
get proxyAddressEnumerator #connectable
proxyAddressEnumeratorConnectable :: AttrLabelProxy "connectable" Source #
defaultPort
The default port to use if ProxyAddressEnumerator:uri does not specify one.
Since: 2.38
data ProxyAddressEnumeratorDefaultPortPropertyInfo Source #
Instances
| AttrInfo ProxyAddressEnumeratorDefaultPortPropertyInfo Source # | |||||||||||||||||||||||||||||||||
Defined in GI.Gio.Objects.ProxyAddressEnumerator Associated Types
Methods attrGet :: AttrBaseTypeConstraint ProxyAddressEnumeratorDefaultPortPropertyInfo o => o -> IO (AttrGetType ProxyAddressEnumeratorDefaultPortPropertyInfo) # attrSet :: (AttrBaseTypeConstraint ProxyAddressEnumeratorDefaultPortPropertyInfo o, AttrSetTypeConstraint ProxyAddressEnumeratorDefaultPortPropertyInfo b) => o -> b -> IO () # attrClear :: AttrBaseTypeConstraint ProxyAddressEnumeratorDefaultPortPropertyInfo o => o -> IO () # attrConstruct :: (AttrBaseTypeConstraint ProxyAddressEnumeratorDefaultPortPropertyInfo o, AttrSetTypeConstraint ProxyAddressEnumeratorDefaultPortPropertyInfo b) => b -> IO (GValueConstruct o) # attrTransfer :: (AttrBaseTypeConstraint ProxyAddressEnumeratorDefaultPortPropertyInfo o, AttrTransferTypeConstraint ProxyAddressEnumeratorDefaultPortPropertyInfo b) => Proxy o -> b -> IO (AttrTransferType ProxyAddressEnumeratorDefaultPortPropertyInfo) # | |||||||||||||||||||||||||||||||||
| type AttrAllowedOps ProxyAddressEnumeratorDefaultPortPropertyInfo Source # | |||||||||||||||||||||||||||||||||
| type AttrBaseTypeConstraint ProxyAddressEnumeratorDefaultPortPropertyInfo Source # | |||||||||||||||||||||||||||||||||
| type AttrGetType ProxyAddressEnumeratorDefaultPortPropertyInfo Source # | |||||||||||||||||||||||||||||||||
| type AttrLabel ProxyAddressEnumeratorDefaultPortPropertyInfo Source # | |||||||||||||||||||||||||||||||||
Defined in GI.Gio.Objects.ProxyAddressEnumerator | |||||||||||||||||||||||||||||||||
| type AttrOrigin ProxyAddressEnumeratorDefaultPortPropertyInfo Source # | |||||||||||||||||||||||||||||||||
| type AttrSetTypeConstraint ProxyAddressEnumeratorDefaultPortPropertyInfo Source # | |||||||||||||||||||||||||||||||||
| type AttrTransferType ProxyAddressEnumeratorDefaultPortPropertyInfo Source # | |||||||||||||||||||||||||||||||||
| type AttrTransferTypeConstraint ProxyAddressEnumeratorDefaultPortPropertyInfo Source # | |||||||||||||||||||||||||||||||||
constructProxyAddressEnumeratorDefaultPort :: (IsProxyAddressEnumerator o, MonadIO m) => Word32 -> m (GValueConstruct o) Source #
Construct a GValueConstruct with valid value for the “default-port” property. This is rarely needed directly, but it is used by new.
getProxyAddressEnumeratorDefaultPort :: (MonadIO m, IsProxyAddressEnumerator o) => o -> m Word32 Source #
Get the value of the “default-port” property.
When overloading is enabled, this is equivalent to
get proxyAddressEnumerator #defaultPort
proxyAddressEnumeratorDefaultPort :: AttrLabelProxy "defaultPort" Source #
proxyResolver
The proxy resolver to use.
Since: 2.36
data ProxyAddressEnumeratorProxyResolverPropertyInfo Source #
Instances
| AttrInfo ProxyAddressEnumeratorProxyResolverPropertyInfo Source # | |||||||||||||||||||||||||||||||||
Defined in GI.Gio.Objects.ProxyAddressEnumerator Associated Types
Methods attrGet :: AttrBaseTypeConstraint ProxyAddressEnumeratorProxyResolverPropertyInfo o => o -> IO (AttrGetType ProxyAddressEnumeratorProxyResolverPropertyInfo) # attrSet :: (AttrBaseTypeConstraint ProxyAddressEnumeratorProxyResolverPropertyInfo o, AttrSetTypeConstraint ProxyAddressEnumeratorProxyResolverPropertyInfo b) => o -> b -> IO () # attrClear :: AttrBaseTypeConstraint ProxyAddressEnumeratorProxyResolverPropertyInfo o => o -> IO () # attrConstruct :: (AttrBaseTypeConstraint ProxyAddressEnumeratorProxyResolverPropertyInfo o, AttrSetTypeConstraint ProxyAddressEnumeratorProxyResolverPropertyInfo b) => b -> IO (GValueConstruct o) # attrTransfer :: (AttrBaseTypeConstraint ProxyAddressEnumeratorProxyResolverPropertyInfo o, AttrTransferTypeConstraint ProxyAddressEnumeratorProxyResolverPropertyInfo b) => Proxy o -> b -> IO (AttrTransferType ProxyAddressEnumeratorProxyResolverPropertyInfo) # | |||||||||||||||||||||||||||||||||
| type AttrAllowedOps ProxyAddressEnumeratorProxyResolverPropertyInfo Source # | |||||||||||||||||||||||||||||||||
Defined in GI.Gio.Objects.ProxyAddressEnumerator | |||||||||||||||||||||||||||||||||
| type AttrBaseTypeConstraint ProxyAddressEnumeratorProxyResolverPropertyInfo Source # | |||||||||||||||||||||||||||||||||
| type AttrGetType ProxyAddressEnumeratorProxyResolverPropertyInfo Source # | |||||||||||||||||||||||||||||||||
| type AttrLabel ProxyAddressEnumeratorProxyResolverPropertyInfo Source # | |||||||||||||||||||||||||||||||||
Defined in GI.Gio.Objects.ProxyAddressEnumerator | |||||||||||||||||||||||||||||||||
| type AttrOrigin ProxyAddressEnumeratorProxyResolverPropertyInfo Source # | |||||||||||||||||||||||||||||||||
| type AttrSetTypeConstraint ProxyAddressEnumeratorProxyResolverPropertyInfo Source # | |||||||||||||||||||||||||||||||||
| type AttrTransferType ProxyAddressEnumeratorProxyResolverPropertyInfo Source # | |||||||||||||||||||||||||||||||||
| type AttrTransferTypeConstraint ProxyAddressEnumeratorProxyResolverPropertyInfo Source # | |||||||||||||||||||||||||||||||||
clearProxyAddressEnumeratorProxyResolver :: (MonadIO m, IsProxyAddressEnumerator o) => o -> m () Source #
Set the value of the “proxy-resolver” property to Nothing.
When overloading is enabled, this is equivalent to
clear #proxyResolver
constructProxyAddressEnumeratorProxyResolver :: (IsProxyAddressEnumerator o, MonadIO m, IsProxyResolver a) => a -> m (GValueConstruct o) Source #
Construct a GValueConstruct with valid value for the “proxy-resolver” property. This is rarely needed directly, but it is used by new.
getProxyAddressEnumeratorProxyResolver :: (MonadIO m, IsProxyAddressEnumerator o) => o -> m (Maybe ProxyResolver) Source #
Get the value of the “proxy-resolver” property.
When overloading is enabled, this is equivalent to
get proxyAddressEnumerator #proxyResolver
proxyAddressEnumeratorProxyResolver :: AttrLabelProxy "proxyResolver" Source #
setProxyAddressEnumeratorProxyResolver :: (MonadIO m, IsProxyAddressEnumerator o, IsProxyResolver a) => o -> a -> m () Source #
Set the value of the “proxy-resolver” property.
When overloading is enabled, this is equivalent to
setproxyAddressEnumerator [ #proxyResolver:=value ]
uri
The destination URI. Use none:// for a generic socket.
data ProxyAddressEnumeratorUriPropertyInfo Source #
Instances
| AttrInfo ProxyAddressEnumeratorUriPropertyInfo Source # | |||||||||||||||||||||||||||||||||
Defined in GI.Gio.Objects.ProxyAddressEnumerator Associated Types
Methods attrGet :: AttrBaseTypeConstraint ProxyAddressEnumeratorUriPropertyInfo o => o -> IO (AttrGetType ProxyAddressEnumeratorUriPropertyInfo) # attrSet :: (AttrBaseTypeConstraint ProxyAddressEnumeratorUriPropertyInfo o, AttrSetTypeConstraint ProxyAddressEnumeratorUriPropertyInfo b) => o -> b -> IO () # attrClear :: AttrBaseTypeConstraint ProxyAddressEnumeratorUriPropertyInfo o => o -> IO () # attrConstruct :: (AttrBaseTypeConstraint ProxyAddressEnumeratorUriPropertyInfo o, AttrSetTypeConstraint ProxyAddressEnumeratorUriPropertyInfo b) => b -> IO (GValueConstruct o) # attrTransfer :: (AttrBaseTypeConstraint ProxyAddressEnumeratorUriPropertyInfo o, AttrTransferTypeConstraint ProxyAddressEnumeratorUriPropertyInfo b) => Proxy o -> b -> IO (AttrTransferType ProxyAddressEnumeratorUriPropertyInfo) # | |||||||||||||||||||||||||||||||||
| type AttrAllowedOps ProxyAddressEnumeratorUriPropertyInfo Source # | |||||||||||||||||||||||||||||||||
Defined in GI.Gio.Objects.ProxyAddressEnumerator | |||||||||||||||||||||||||||||||||
| type AttrBaseTypeConstraint ProxyAddressEnumeratorUriPropertyInfo Source # | |||||||||||||||||||||||||||||||||
| type AttrGetType ProxyAddressEnumeratorUriPropertyInfo Source # | |||||||||||||||||||||||||||||||||
| type AttrLabel ProxyAddressEnumeratorUriPropertyInfo Source # | |||||||||||||||||||||||||||||||||
Defined in GI.Gio.Objects.ProxyAddressEnumerator | |||||||||||||||||||||||||||||||||
| type AttrOrigin ProxyAddressEnumeratorUriPropertyInfo Source # | |||||||||||||||||||||||||||||||||
| type AttrSetTypeConstraint ProxyAddressEnumeratorUriPropertyInfo Source # | |||||||||||||||||||||||||||||||||
| type AttrTransferType ProxyAddressEnumeratorUriPropertyInfo Source # | |||||||||||||||||||||||||||||||||
| type AttrTransferTypeConstraint ProxyAddressEnumeratorUriPropertyInfo Source # | |||||||||||||||||||||||||||||||||
constructProxyAddressEnumeratorUri :: (IsProxyAddressEnumerator o, MonadIO m) => Text -> m (GValueConstruct o) Source #
Construct a GValueConstruct with valid value for the “uri” property. This is rarely needed directly, but it is used by new.
getProxyAddressEnumeratorUri :: (MonadIO m, IsProxyAddressEnumerator o) => o -> m (Maybe Text) Source #
Get the value of the “uri” property.
When overloading is enabled, this is equivalent to
get proxyAddressEnumerator #uri
proxyAddressEnumeratorUri :: AttrLabelProxy "uri" Source #