| Copyright | Will Thompson and Iñaki García Etxebarria |
|---|---|
| License | LGPL-2.1 |
| Maintainer | Iñaki García Etxebarria |
| Safe Haskell | None |
| Language | Haskell2010 |
GI.Gio.Structs.IOModuleScope
Contents
Description
Represents a scope for loading IO modules. A scope can be used for blocking duplicate modules, or blocking a module you don't want to load.
The scope can be used with g_io_modules_load_all_in_directory_with_scope()
or ioModulesScanAllInDirectoryWithScope.
Since: 2.30
Synopsis
- newtype IOModuleScope = IOModuleScope (ManagedPtr IOModuleScope)
- type family ResolveIOModuleScopeMethod (t :: Symbol) o where ...
- data IOModuleScopeBlockMethodInfo
- iOModuleScopeBlock :: (HasCallStack, MonadIO m) => IOModuleScope -> Text -> m ()
- data IOModuleScopeFreeMethodInfo
- iOModuleScopeFree :: (HasCallStack, MonadIO m) => IOModuleScope -> m ()
Exported types
newtype IOModuleScope Source #
Memory-managed wrapper type.
Constructors
| IOModuleScope (ManagedPtr IOModuleScope) |
Instances
Methods
Click to display all available methods, including inherited ones
type family ResolveIOModuleScopeMethod (t :: Symbol) o where ... Source #
Equations
| ResolveIOModuleScopeMethod "block" o = IOModuleScopeBlockMethodInfo | |
| ResolveIOModuleScopeMethod "free" o = IOModuleScopeFreeMethodInfo | |
| ResolveIOModuleScopeMethod l o = MethodResolutionFailed l o :: Type |
block
data IOModuleScopeBlockMethodInfo Source #
Instances
| (signature ~ (Text -> m ()), MonadIO m) => OverloadedMethod IOModuleScopeBlockMethodInfo IOModuleScope signature Source # | |
Defined in GI.Gio.Structs.IOModuleScope Methods overloadedMethod :: IOModuleScope -> signature # | |
| OverloadedMethodInfo IOModuleScopeBlockMethodInfo IOModuleScope Source # | |
Defined in GI.Gio.Structs.IOModuleScope Methods | |
Arguments
| :: (HasCallStack, MonadIO m) | |
| => IOModuleScope |
|
| -> Text |
|
| -> m () |
Block modules with the given basename from being loaded when
this scope is used with ioModulesScanAllInDirectoryWithScope
or g_io_modules_load_all_in_directory_with_scope().
Since: 2.30
free
data IOModuleScopeFreeMethodInfo Source #
Instances
| (signature ~ m (), MonadIO m) => OverloadedMethod IOModuleScopeFreeMethodInfo IOModuleScope signature Source # | |
Defined in GI.Gio.Structs.IOModuleScope Methods overloadedMethod :: IOModuleScope -> signature # | |
| OverloadedMethodInfo IOModuleScopeFreeMethodInfo IOModuleScope Source # | |
Defined in GI.Gio.Structs.IOModuleScope Methods | |
Arguments
| :: (HasCallStack, MonadIO m) | |
| => IOModuleScope |
|
| -> m () |
Free a module scope.
Since: 2.30