| Copyright | Will Thompson and Iñaki García Etxebarria |
|---|---|
| License | LGPL-2.1 |
| Maintainer | Iñaki García Etxebarria |
| Safe Haskell | None |
| Language | Haskell2010 |
GI.Gio.Structs.StaticResource
Contents
Description
GStaticResource is an opaque data structure and can only be accessed
using the following functions.
Synopsis
- newtype StaticResource = StaticResource (ManagedPtr StaticResource)
- newZeroStaticResource :: MonadIO m => m StaticResource
- type family ResolveStaticResourceMethod (t :: Symbol) o where ...
- data StaticResourceFiniMethodInfo
- staticResourceFini :: (HasCallStack, MonadIO m) => StaticResource -> m ()
- data StaticResourceGetResourceMethodInfo
- staticResourceGetResource :: (HasCallStack, MonadIO m) => StaticResource -> m Resource
- data StaticResourceInitMethodInfo
- staticResourceInit :: (HasCallStack, MonadIO m) => StaticResource -> m ()
Exported types
newtype StaticResource Source #
Memory-managed wrapper type.
Constructors
| StaticResource (ManagedPtr StaticResource) |
Instances
newZeroStaticResource :: MonadIO m => m StaticResource Source #
Construct a StaticResource struct initialized to zero.
Methods
Click to display all available methods, including inherited ones
type family ResolveStaticResourceMethod (t :: Symbol) o where ... Source #
Equations
| ResolveStaticResourceMethod "fini" o = StaticResourceFiniMethodInfo | |
| ResolveStaticResourceMethod "init" o = StaticResourceInitMethodInfo | |
| ResolveStaticResourceMethod "getResource" o = StaticResourceGetResourceMethodInfo | |
| ResolveStaticResourceMethod l o = MethodResolutionFailed l o :: Type |
fini
data StaticResourceFiniMethodInfo Source #
Instances
| (signature ~ m (), MonadIO m) => OverloadedMethod StaticResourceFiniMethodInfo StaticResource signature Source # | |
Defined in GI.Gio.Structs.StaticResource Methods overloadedMethod :: StaticResource -> signature # | |
| OverloadedMethodInfo StaticResourceFiniMethodInfo StaticResource Source # | |
Defined in GI.Gio.Structs.StaticResource Methods | |
Arguments
| :: (HasCallStack, MonadIO m) | |
| => StaticResource |
|
| -> m () |
Finalizes a Resource initialized by
staticResourceInit.
This is normally used by code generated by `glib-compile-resources` and is not typically used by other code.
Since: 2.32
getResource
data StaticResourceGetResourceMethodInfo Source #
Instances
| (signature ~ m Resource, MonadIO m) => OverloadedMethod StaticResourceGetResourceMethodInfo StaticResource signature Source # | |
Defined in GI.Gio.Structs.StaticResource Methods overloadedMethod :: StaticResource -> signature # | |
| OverloadedMethodInfo StaticResourceGetResourceMethodInfo StaticResource Source # | |
Defined in GI.Gio.Structs.StaticResource Methods | |
staticResourceGetResource Source #
Arguments
| :: (HasCallStack, MonadIO m) | |
| => StaticResource |
|
| -> m Resource | Returns: a |
Gets the Resource that was registered by a call to
staticResourceInit.
This is normally used by code generated by `glib-compile-resources` and is not typically used by other code.
Since: 2.32
init
data StaticResourceInitMethodInfo Source #
Instances
| (signature ~ m (), MonadIO m) => OverloadedMethod StaticResourceInitMethodInfo StaticResource signature Source # | |
Defined in GI.Gio.Structs.StaticResource Methods overloadedMethod :: StaticResource -> signature # | |
| OverloadedMethodInfo StaticResourceInitMethodInfo StaticResource Source # | |
Defined in GI.Gio.Structs.StaticResource Methods | |
Arguments
| :: (HasCallStack, MonadIO m) | |
| => StaticResource |
|
| -> m () |
Initializes a Resource from static data using a
StaticResource.
This is normally used by code generated by `glib-compile-resources` and is not typically used by other code.
Since: 2.32